; Tutorial Example Database 2
; Test seeds near Champaign Illinois

 	include asm.inc 	; include this in ALL .asm files!
	include dumper.inc	; we're dumping data from this file

.data
dumper_data	DUMPERDATA	{the_data, the_data_size, 'test.bin'}

the_data	equ	$


; DATABASE HEADER *************************************************************
	dw	0001			;00 world set number (not saved to filelist)
					;   0=off 1=fs5 default world
	dd	0004b0000h		;02 N bound Meter units
	dd	0003e0000h		;06 S bound
	dd	0c4000000h		;10 E bound 32-bit pseudo
	dd	0bf000000h		;14 W bound
	dd	0			;18 VOR_DATA
	dw	0			;22 lowest vor freq  (channel 0-199)
	dw	0			;24 highest vor freq (108.00-117.95)
	dd	0			;26 seeds level 8
	dd	0			;30 seeds level 9
	dd	0			;34 seeds level 10
	dd	0			;38 seeds level 11
	dd	0			;42 seeds level 12
	dd	synth_seeds_13-the_data ;46 seeds level 13
	dd	0			;50 seeds level 14
	dd	0			;54 seeds level 15
	dd	0			;58 OBJECT_DATA
	dd	0			;62 LIBRARY_DATA
	dd	0			;66 FACILITIES_DATA
	dd	0			;70 ANCHOR POINT DATA
	dd	0			;74 COM RADIO DATA
	dd	0			;78 ADF DATA
	dd	0			;82 DYNAMIC OBJECT PATHS
	dd	0,0			;86 Library id min
	dd	0,0			;94 Library id max
	dd	0			;102 MISC_DATA (ground alt db)
	dd	0			;106 TITLE AND DESCRIPTION DATA
	dd	0			;110
	dd	0			;114 EXCEPTION LIST PTR
	dd	0			;118
	dd	0			;122 (not saved to filelist)
	dw	0			;126 (not saved to filelist)
					;128


; ENTITY OPCODES **************************************************************

EOL	macro
        db	0
        endm

LATBAND_REL	macro	latmin,latmax,band_addr
        db	21
        dw	latmin			;;lat min (inclusive) 512M units
        dw	latmax			;;lat max (exclusive)
        dd	(offset band_addr) - (offset rel_base)	;;32-bit rel_base relative ptr
        endm

COORD_LATBAND_REL	macro	coord_value,band_addr
	db	22
	dw	coord_value
	dd	(offset band_addr) - (offset rel_base)	;;32-bit rel_base relative ptr
	endm

LARGE_OBJECT_HEADER	macro	latitude,longitude,object_end
	LOCAL	opcode
opcode	db	5
	dd	latitude,longitude
	db	100			;;image power
	dw	(offset object_end) - (offset opcode)
	endm

SEED_ENTITY	macro	longitude,seedtype1,seedtype2,altM256,altM,altfract
	db	4			;;00 opcode
	dw	longitude		;;01 longitude coord
	dw	seedtype1		;;03 seed type
	dw	seedtype2		;;05 MSB(status):LSB(class)
	db	altfract,altM,altM256	;;07 altitude ii.f M
	endm

SEED_BAND	macro	west,east
	db 5				;;00 opcode
	dw west				;;01 longitude coord westmost seed
	dw east				;;03 longitude coord eastmost seed
	endm

BAND_ELEMENT	macro	seedtype1,seedtype2,altM256,altM,altfract
	dw seedtype1			;;00 seed type
	dw seedtype2			;;00 seed type
	db altfract,altM,altM256	;;04 altitude ii.f M
	endm


hole		equ	0
seed_land	equ 	0001h
seed_water	equ	0000h
seed_mountain	equ	0000h
seed_coast	equ	0000h
seed_broadleaf	equ	0001h
seed_needle	equ	0002h
seed_crops	equ	0004h
seed_prarie	equ	0005h
seed_arid	equ	0006h
seed_desert	equ	0007h
seed_green	equ	0080h
seed_smallcity	equ	0081h
seed_medcity	equ	0082h
seed_burb1	equ	0083h
seed_lake	equ	0084h
seed_burb2	equ	0085h
seed_burb3	equ	0086h
seed_hills	equ	0088h
seed_dunes	equ	0089h
seed_hirise	equ	008ah
seed_midrise	equ	008bh
seed_urban1	equ	008ch
seed_urban	equ	008ch
seed_urbsub	equ	008dh
ignore		equ	0000h
flat_seed	equ	1111h
mountain	equ	2222h
outside		equ	3333h
inside		equ	4444h

; seed classes
SEED_CLASS_HOLE			equ	0000h
SEED_CLASS_FLAT			equ	0011h
SEED_CLASS_MNT			equ	0022h
SEED_CLASS_OUTSIDE_COAST	equ	0033h
SEED_CLASS_INSIDE_COAST		equ	0044h
SEED_CLASS_FLAT_ALTITUDE_LOCK	equ	0055h		;; is this used??????

; seed status
SEED_STATUS_LOW_PRIORITY	equ	0000h		;; all status bits are ignored except Fx
SEED_STATUS_HI_PRIORITY_0	equ	0F000h
SEED_STATUS_HI_PRIORITY_1	equ	0F100h
SEED_STATUS_HI_PRIORITY_2	equ	0F200h
SEED_STATUS_HI_PRIORITY_3	equ	0F300h
SEED_STATUS_HI_PRIORITY_4	equ	0F400h
SEED_STATUS_HI_PRIORITY_5	equ	0F500h
SEED_STATUS_HI_PRIORITY_6	equ	0F600h
SEED_STATUS_HI_PRIORITY_7	equ	0F700h
SEED_STATUS_HI_PRIORITY_8	equ	0F800h
SEED_STATUS_HI_PRIORITY_9	equ	0F900h
SEED_STATUS_HI_PRIORITY_A	equ	0FA00h
SEED_STATUS_HI_PRIORITY_B	equ	0FB00h
SEED_STATUS_HI_PRIORITY_C	equ	0FC00h
SEED_STATUS_HI_PRIORITY_D	equ	0FD00h
SEED_STATUS_HI_PRIORITY_E	equ	0FE00h
SEED_STATUS_HI_PRIORITY_F	equ	0FF00h


; SEED type information for mountains (class 22h)
; NOTE: the MSB (bytes 3 & 4 of the seed type word) of the type
; information for mountain class seeds is used internally to
; determine heights along edges and corners

; mountain height is set by byte 2 of seed type word
MNT_SEED_HEIGHT_6k_FT		equ	0000h
MNT_SEED_HEIGHT_750_FT		equ	0010h
MNT_SEED_HEIGHT_1500_FT		equ	0020h
MNT_SEED_HEIGHT_3k_FT		equ	0030h
MNT_SEED_HEIGHT_9k_FT		equ	0040h
MNT_SEED_HEIGHT_12k_FT		equ	0050h
MNT_SEED_HEIGHT_18k_FT		equ	0060h
MNT_SEED_HEIGHT_24k_FT		equ	0070h

; mountain coverage is set by byte 1 of seed type word
MNT_SEED_COVERAGE_WATER		equ	0000h
MNT_SEED_COVERAGE_BROADLEAF	equ	0001h
MNT_SEED_COVERAGE_NEEDLELEAF	equ	0002h
MNT_SEED_COVERAGE_TROPICAL	equ	0003h
MNT_SEED_COVERAGE_CROPS		equ	0004h
MNT_SEED_COVERAGE_PRARIE	equ	0005h
MNT_SEED_COVERAGE_ARID		equ	0006h
MNT_SEED_COVERAGE_DESERT	equ	0007h
MNT_SEED_COVERAGE_TUNDRA	equ	0008h
MNT_SEED_COVERAGE_ICE		equ	0009h
MNT_SEED_COVERAGE_SWAMP		equ	000Ah

coast_w				equ	0100h
coast_s				equ	0200h
coast_sw			equ	0300h
coast_e				equ	0400h
coast_ew			equ	0500h
coast_se			equ	0600h
coast_esw			equ	0700h
coast_n				equ	0800h
coast_nw			equ	0900h
coast_ns			equ	0a00h
coast_nsw			equ	0b00h
coast_ne			equ	0c00h
coast_nwe			equ	0d00h
coast_nes			equ	0e00h
coast_nsew			equ	0f00h


; SEED DATABASE ***************************************************************
synth_seeds_13	label	word
rel_base	= synth_seeds_13
	COORD_LATBAND_REL	00988,levl_13_lat_00988
	COORD_LATBAND_REL	00989,levl_13_lat_00989
	COORD_LATBAND_REL	00990,levl_13_lat_00990
	EOL


levl_13_lat_00988	label	word
SEED_ENTITY	6183, seed_needle+	coast_w,	outside,	0,230,0
SEED_ENTITY	6184, seed_needle+	coast_s,	outside,	0,230,0
SEED_ENTITY	6185, seed_needle+	coast_sw,	outside,	0,230,0
SEED_ENTITY	6186, seed_needle+	coast_e,	outside,	0,230,0
SEED_ENTITY	6187, seed_urban+	coast_ew,	outside,	0,230,0
SEED_ENTITY	6188, seed_urban+	coast_se,	outside,	0,230,0
SEED_ENTITY	6189, seed_urban+	coast_esw,	outside,	0,230,0
SEED_ENTITY	6190, seed_urban+	coast_n,	outside,	0,230,0
SEED_ENTITY	6191, seed_arid+	coast_nw,	outside,	0,230,0
SEED_ENTITY	6192, seed_arid+	coast_ns,	outside,	0,230,0
SEED_ENTITY	6193, seed_arid+	coast_nsw,	outside,	0,230,0
SEED_ENTITY	6194, seed_broadleaf+	coast_ne,	outside,	0,230,0
SEED_ENTITY	6195, seed_broadleaf+	coast_nwe,	outside,	0,230,0
SEED_ENTITY	6196, seed_broadleaf+	coast_nes,	outside,	0,230,0
SEED_ENTITY	6197, seed_broadleaf+	coast_nsew,	outside,	0,230,0
EOL


levl_13_lat_00989	label	word
SEED_ENTITY	6183, seed_green,	flat_seed,	0,230,0
SEED_ENTITY	6184, seed_smallcity,	flat_seed,	0,230,0
SEED_ENTITY	6185, seed_medcity,	flat_seed,	0,230,0
SEED_ENTITY	6186, seed_burb1,	flat_seed,	0,230,0
SEED_ENTITY	6187, seed_burb2,	flat_seed,	0,230,0
SEED_ENTITY	6188, seed_burb3,	flat_seed,	0,230,0
SEED_ENTITY	6189, seed_arid,	flat_seed,	0,230,0
SEED_ENTITY	6190, seed_desert,	flat_seed,	0,230,0
SEED_ENTITY	6191, seed_hirise,	flat_seed,	0,230,0
SEED_ENTITY	6192, seed_midrise,	flat_seed,	0,230,0
SEED_ENTITY	6193, seed_urban1,	flat_seed,	0,230,0
SEED_ENTITY	6194, seed_urbsub,	flat_seed,	0,230,0
SEED_ENTITY	6195, seed_broadleaf,	flat_seed,	0,230,0
SEED_ENTITY	6196, seed_needle,	flat_seed,	0,230,0
SEED_ENTITY	6197, seed_crops,	flat_seed,	0,230,0
SEED_ENTITY	6198, seed_prarie,	flat_seed,	0,230,0
EOL

levl_13_lat_00990	label	word
SEED_ENTITY	6183, seed_urban,	flat_seed,	0,230,0
SEED_ENTITY	6184, MNT_SEED_HEIGHT_1500_FT + MNT_SEED_COVERAGE_WATER, 	SEED_STATUS_LOW_PRIORITY + SEED_CLASS_MNT, 0,230,0
SEED_ENTITY	6185, MNT_SEED_HEIGHT_1500_FT + MNT_SEED_COVERAGE_BROADLEAF, 	SEED_STATUS_LOW_PRIORITY + SEED_CLASS_MNT, 0,230,0
SEED_ENTITY	6186, MNT_SEED_HEIGHT_1500_FT + MNT_SEED_COVERAGE_NEEDLELEAF,	SEED_STATUS_LOW_PRIORITY + SEED_CLASS_MNT, 0,230,0
SEED_ENTITY	6187, MNT_SEED_HEIGHT_1500_FT + MNT_SEED_COVERAGE_TROPICAL, 	SEED_STATUS_LOW_PRIORITY + SEED_CLASS_MNT, 0,230,0
SEED_ENTITY	6188, MNT_SEED_HEIGHT_1500_FT + MNT_SEED_COVERAGE_CROPS, 	SEED_STATUS_LOW_PRIORITY + SEED_CLASS_MNT, 0,230,0
SEED_ENTITY	6189, MNT_SEED_HEIGHT_1500_FT + MNT_SEED_COVERAGE_PRARIE, 	SEED_STATUS_LOW_PRIORITY + SEED_CLASS_MNT, 0,230,0
SEED_ENTITY	6190, MNT_SEED_HEIGHT_1500_FT + MNT_SEED_COVERAGE_ARID, 	SEED_STATUS_LOW_PRIORITY + SEED_CLASS_MNT, 0,230,0
SEED_ENTITY	6191, MNT_SEED_HEIGHT_1500_FT + MNT_SEED_COVERAGE_DESERT, 	SEED_STATUS_LOW_PRIORITY + SEED_CLASS_MNT, 0,230,0
SEED_ENTITY	6192, MNT_SEED_HEIGHT_1500_FT + MNT_SEED_COVERAGE_TUNDRA, 	SEED_STATUS_LOW_PRIORITY + SEED_CLASS_MNT, 0,230,0
SEED_ENTITY	6193, MNT_SEED_HEIGHT_1500_FT + MNT_SEED_COVERAGE_ICE, 		SEED_STATUS_LOW_PRIORITY + SEED_CLASS_MNT, 0,230,0
SEED_ENTITY	6194, MNT_SEED_HEIGHT_1500_FT + MNT_SEED_COVERAGE_SWAMP, 	SEED_STATUS_LOW_PRIORITY + SEED_CLASS_MNT, 0,230,0
EOL

the_data_size	equ	$ - the_data
	end

