// gauges.h
// Copyright (c) 1997 Microsoft Corporation.  All rights reserved.
//

#pragma pack(4)

// Flightsim calling convention
#define	FSAPI	__stdcall

//
// Common Flight Simulator Constant Definitions
//

#ifndef VOID
#define VOID	void
#endif

// Logical True/False Constants
#ifndef FALSE
#define FALSE	0
#endif

#ifndef TRUE
#define TRUE	1
#endif

// Pointer Constant
#ifndef	NULL
#define NULL	((void *)0)			// empty handle
#endif

// Misc Constants
#define NULLPTR	NULL				// empty pointer
#define CR		0x0d				// ASCII carriage return
#define LF		0x0a				// ASCII line feed
#define FLAGS0	0					// no flags set in a FLAGSn type variable
#define FLAGS1	-1					// all flags set in a FLAGSn type variable

// Bit Flag Constants
#define BIT0	0x00000001
#define BIT1	0x00000002
#define BIT2	0x00000004
#define BIT3	0x00000008
#define BIT4	0x00000010
#define BIT5	0x00000020
#define BIT6	0x00000040
#define BIT7	0x00000080
#define BIT8	0x00000100
#define BIT9	0x00000200
#define BIT10	0x00000400
#define BIT11	0x00000800
#define BIT12	0x00001000
#define BIT13	0x00002000
#define BIT14	0x00004000
#define BIT15	0x00008000
#define BIT16	0x00010000
#define BIT17	0x00020000
#define BIT18	0x00040000
#define BIT19	0x00080000
#define BIT20	0x00100000
#define BIT21	0x00200000
#define BIT22	0x00400000
#define BIT23	0x00800000
#define BIT24	0x01000000
#define BIT25	0x02000000
#define BIT26	0x04000000
#define BIT27	0x08000000
#define BIT28	0x10000000
#define BIT29	0x20000000
#define BIT30	0x40000000
#define BIT31	0x80000000

// integer data types limits
#define UINT8_MIN	0
#define UINT8_MAX	255
#define SINT8_MIN	-128
#define SINT8_MAX	 127
#define UINT16_MIN	0
#define UINT16_MAX	65535
#define SINT16_MIN	-32768
#define SINT16_MAX	32767
#define UINT32_MIN	0
#define UINT32_MAX	4294967295
#define SINT32_MIN	((signed int) BIT31)
#define SINT32_MAX	2147483647

// fractional data types limits
#define UFRAC8_MIN	0
#define UFRAC8_MAX	255
#define SFRAC8_MIN	-128
#define SFRAC8_MAX	127
#define UFRAC16_MIN	0
#define UFRAC16_MAX	65535
#define SFRAC16_MIN	-32768
#define SFRAC16_MAX	32767
#define UFRAC32_MIN	0
#define UFRAC32_MAX	4294967295
#define SFRAC32_MIN	-2147483648
#define SFRAC32_MAX	2147483647

// flag values for engine_control_select variable
#define ENGINE_CONTROL_SELECT_NONE	0		// no engines
#define ENGINE_CONTROL_SELECT_1		BIT0	// engine 1
#define ENGINE_CONTROL_SELECT_2		BIT1	// engine 2
#define ENGINE_CONTROL_SELECT_3		BIT2	// engine 3
#define ENGINE_CONTROL_SELECT_4		BIT3	// engine 4

// enum values for prop_adv_sel variable
#define PROP_ADV_SEL_FIXED			0		// fixed pitch propeller
#define PROP_ADV_SEL_AUTO			1		// variable pitch propeller, automatic
#define PROP_ADV_SEL_MANUAL			2		// variable pitch propeller, manual

// realism_systems values
#define	REALISM_SYSTEMS_ELEV_TRIM	BIT1	// enable elevator trim realism (ratchet effect)
#define	REALISM_SYSTEMS_GYRO_DRIFT	BIT2	// enable gyro drift
#define	REALISM_SYSTEMS_LIGHT_BURN	BIT3	// enable light burnout if on too long during day
#define	REALISM_SYSTEMS_FAST_THROT	BIT4	// enable fast throttle kill engine
#define	REALISM_SYSTEMS_INS_LIGHTS	BIT5	// enable instrument light needed at night to see panel
#define	REALISM_SYSTEMS_BARO_DRIFT	BIT6	// enable barometric pressure drift

// vor1_tf_flag and vor2_tf_flag
#define	VOR_TF_FLAG_OFF			0
#define	VOR_TF_FLAG_TO			1
#define	VOR_TF_FLAG_FROM		2

// Back course flags for VOR gauges
#define	BC_FLAG_BACKCOURSE_AVAILABLE	BIT0
#define	BC_FLAG_LOCALIZER_TUNED_IN		BIT1
#define	BC_FLAG_ON_BACKCOURSE			BIT2
#define	BC_FLAG_STATION_ACTIVE			BIT7

// sim_speed constants
#define	SIM_SPEED_QUARTER	0x0040
#define	SIM_SPEED_HALF		0x0080
#define	SIM_SPEED_1X		0x0100
#define	SIM_SPEED_2X		0x0200
#define	SIM_SPEED_4X		0x0400
#define	SIM_SPEED_8X		0x0800
#define	SIM_SPEED_16X		0x1000
#define	SIM_SPEED_32X		0x2000
#define	SIM_SPEED_64X		0x4000
#define	SIM_SPEED_128X		0x8000

#define	SIM_SPEED_MIN		SIM_SPEED_QUARTER
#define	SIM_SPEED_MAX		SIM_SPEED_128X

// controls limits
#define	SPOILERS_POS_OFF			0		// spoilers desired position {0=retracted..16k=fully extended}
#define	SPOILERS_POS_FULL			16383
#define	FLAPS_POS_OFF				0		// 0=up, 16383 = full
#define	FLAPS_POS_FULL				16383
#define	GEAR_POS_UP					0		// 0 = up, 16K = dn
#define	GEAR_POS_DOWN				16383

// conversion factors for feet to meters and meters to feet conversions
#define	FEET_TO_METERS_FACTOR		0x4E07625F		// (1 / 3.28084) * (2^32)
#define	METERS_TO_FEET_FACTOR		0x000347E5		// 3.28084 * (2^16)

// defines for VOR_INFO.CODE field
#define	VOR_CODE_IS_LOCALIZER			BIT7	// bit7 = 0= VOR  1= Localizer
#define	VOR_CODE_GLIDESLOPE			    BIT6	// bit6 = 1= Glideslope Available
#define	VOR_CODE_BACKCOURSE_UNAVAIL	    BIT5	// bit5 = 1= no localizer backcourse
#define	VOR_CODE_DME_AT_GLIDE_SLOPE	    BIT4	// bit4 = 1= DME transmitter at Glide Slope Transmitter
#define	VOR_CODE_NAV_UNAVAILABLE	    BIT3	// bit3 = 1= no nav signal available
#define	VOR_CODE_VOICE_AVAILABLE	    BIT2	// bit2 = Voice Available
#define	VOR_CODE_TACAN				    BIT1	// bit1 = TACAN
#define VOR_CODE_DME_AVAILABLE		    BIT0	// bit0 = DME

// defines for engine structure starter variable, note:  magnetos for recip. engines / starters for jet engines
#define ENG_STARTER_MAGNETO_OFF		0	// the following values for reciprocating engines
#define ENG_STARTER_MAGNETO_RIGHT	1
#define ENG_STARTER_MAGNETO_LEFT	2
#define ENG_STARTER_MAGNETO_BOTH	3
#define ENG_STARTER_MAGNETO_START	4
#define ENG_STARTER_STARTER_OFF		0	// the following values for jet engines
#define ENG_STARTER_STARTER_START	1
#define ENG_STARTER_STARTER_GEN		2


// Panel quick help strings
#define	HELPID_MIN								0x0000a000

// cessna strings (0x0000-0x00ff)
#define	HELPID_CESS								HELPID_MIN + 0x0000

#define	HELPID_CESS_ADF							(HELPID_CESS + 0x0000)
#define	HELPID_CESS_ALTIMETER					(HELPID_CESS + 0x0001)
#define	HELPID_CESS_ALTIMETER_SET				(HELPID_CESS + 0x0002)
#define	HELPID_CESS_AIRSPEED					(HELPID_CESS + 0x0003)
#define	HELPID_CESS_ATTITUDE_INDICATOR			(HELPID_CESS + 0x0004)
#define	HELPID_CESS_HEADING_INDICATOR			(HELPID_CESS + 0x0005)
#define	HELPID_CESS_TEMPERATURE					(HELPID_CESS + 0x000e)
#define	HELPID_CESS_CARB_HEAT					(HELPID_CESS + 0x000f)
#define	HELPID_CESS_ZOOM						(HELPID_CESS + 0x0010)
#define	HELPID_CESS_STROBES						(HELPID_CESS + 0x0011)
#define	HELPID_CESS_LANDING_LIGHT				(HELPID_CESS + 0x0012)
#define	HELPID_CESS_AUTOPILOT					(HELPID_CESS + 0x0013)
#define	HELPID_CESS_LANDING_GEAR				(HELPID_CESS + 0x0014)
#define	HELPID_CESS_FLAPS						(HELPID_CESS + 0x0015)
#define	HELPID_CESS_MAGNETOS					(HELPID_CESS + 0x0016)
#define	HELPID_CESS_CLOCK						(HELPID_CESS + 0x0017)
#define	HELPID_CESS_EGT							(HELPID_CESS + 0x0018)
#define	HELPID_CESS_THROTTLE					(HELPID_CESS + 0x0019)
#define	HELPID_CESS_TURN_COORDINATOR			(HELPID_CESS + 0x001a)
#define	HELPID_CESS_VOR1						(HELPID_CESS + 0x001b)
#define	HELPID_CESS_OBS1						(HELPID_CESS + 0x001c)
#define	HELPID_CESS_VOR2						(HELPID_CESS + 0x001d)
#define	HELPID_CESS_OBS2						(HELPID_CESS + 0x001e)
#define	HELPID_CESS_VSI							(HELPID_CESS + 0x001f)
#define	HELPID_CESS_RPM							(HELPID_CESS + 0x0020)
#define	HELPID_CESS_MAN_PRESS					(HELPID_CESS + 0x0021)
#define	HELPID_CESS_OIL_TEMP					(HELPID_CESS + 0x0022)
#define	HELPID_CESS_OIL_PRESS					(HELPID_CESS + 0x0023)
#define	HELPID_CESS_PROP_ADV					(HELPID_CESS + 0x0024)
#define	HELPID_CESS_MIXTURE						(HELPID_CESS + 0x0025)
#define	HELPID_CESS_OUTER_MARKER				(HELPID_CESS + 0x0026)
#define	HELPID_CESS_MIDDLE_MARKER				(HELPID_CESS + 0x0027)
#define	HELPID_CESS_INNER_MARKER				(HELPID_CESS + 0x0028)
#define	HELPID_CESS_FUEL_LEFT					(HELPID_CESS + 0x0029)
#define	HELPID_CESS_FUEL_RIGHT					(HELPID_CESS + 0x002a)
#define	HELPID_CESS_MAG_COMPASS					(HELPID_CESS + 0x002b)
#define	HELPID_CESS_BACK_COURSE_IND				(HELPID_CESS + 0x002c)
#define	HELPID_CESS_HEADING_ADJUST				(HELPID_CESS + 0x002d)
#define	HELPID_CESS_TRIM						(HELPID_CESS + 0x002e)
#define	HELPID_CESS_VACUUM						(HELPID_CESS + 0x002f)
#define	HELPID_CESS_AMPS						(HELPID_CESS + 0x0030)
#define	HELPID_CESS_FUEL_FLOW					(HELPID_CESS + 0x0031)
#define	HELPID_CESS_CHT							(HELPID_CESS + 0x0032)
#define	HELPID_CESS_TAS_CALIBRATION				(HELPID_CESS + 0x0033)
#define	HELPID_CESS_KOHLSMAN					(HELPID_CESS + 0x0034)
#define	HELPID_CESS_PITOT_HEAT					(HELPID_CESS + 0x0035)
#define	HELPID_CESS_SUCTION						(HELPID_CESS + 0x0036)
#define	HELPID_CESS_HEADING_BUG_ADJUST			(HELPID_CESS + 0x0037)
#define	HELPID_CESS_PANEL_LIGHTS_TOGGLE			(HELPID_CESS + 0x0038)
#define	HELPID_CESS_PITOT_HEAT_TOGGLE			(HELPID_CESS + 0x0039)

// lear strings (0x0100-0x01ff)
#define	HELPID_LEAR								HELPID_MIN + 0x0100

#define	HELPID_LEAR_ADF_INDICATOR				(HELPID_LEAR + 0x0000)
#define	HELPID_LEAR_ALTIMETER					(HELPID_LEAR + 0x0001)
#define	HELPID_LEAR_ALTIMETER_SET				(HELPID_LEAR + 0x0002)
#define	HELPID_LEAR_AIRSPEED					(HELPID_LEAR + 0x0003)
#define	HELPID_LEAR_AOA							(HELPID_LEAR + 0x0004)
#define	HELPID_LEAR_ATTITUDE_INDICATOR			(HELPID_LEAR + 0x0005)
#define	HELPID_LEAR_CLOCK						(HELPID_LEAR + 0x0006)
#define	HELPID_LEAR_SIM_RATE					(HELPID_LEAR + 0x0007)
#define	HELPID_LEAR_COMPASS						(HELPID_LEAR + 0x0008)
#define	HELPID_LEAR_TURBINE_SPEED				(HELPID_LEAR + 0x0009)
#define	HELPID_LEAR_TURBINE_TEMP				(HELPID_LEAR + 0x000a)
#define	HELPID_LEAR_FAN_SPEED					(HELPID_LEAR + 0x000b)
#define	HELPID_LEAR_OIL_TEMP					(HELPID_LEAR + 0x000c)
#define	HELPID_LEAR_OIL_PRESSURE				(HELPID_LEAR + 0x000d)
#define	HELPID_LEAR_FUEL_FLOW					(HELPID_LEAR + 0x000e)
#define	HELPID_LEAR_FUEL_QUANTITY				(HELPID_LEAR + 0x000f)
#define	HELPID_LEAR_THRUST_LEVERS				(HELPID_LEAR + 0x0010)
#define	HELPID_LEAR_ENGINE1_LEVER				(HELPID_LEAR + 0x0011)
#define	HELPID_LEAR_ENGINE2_LEVER				(HELPID_LEAR + 0x0012)
#define	HELPID_LEAR_ENGINE_STARTERS				(HELPID_LEAR + 0x0013)
#define	HELPID_LEAR_ENGINE1_STARTER				(HELPID_LEAR + 0x0014)
#define	HELPID_LEAR_ENGINE1_GENERATOR			(HELPID_LEAR + 0x0015)
#define	HELPID_LEAR_ENGINE2_STARTER				(HELPID_LEAR + 0x0016)
#define	HELPID_LEAR_ENGINE2_GENERATOR			(HELPID_LEAR + 0x0017)
#define	HELPID_LEAR_HEADING_INDICATOR			(HELPID_LEAR + 0x0018)
#define	HELPID_LEAR_HEADING_ADJUST				(HELPID_LEAR + 0x0019)
#define	HELPID_LEAR_ZOOM_INDICATOR				(HELPID_LEAR + 0x001a)
#define	HELPID_LEAR_AUTOPILOT_INDICATOR			(HELPID_LEAR + 0x001b)
#define	HELPID_LEAR_ALT_HOLD					(HELPID_LEAR + 0x001c)
#define	HELPID_LEAR_HEADING_HOLD				(HELPID_LEAR + 0x001d)
#define	HELPID_LEAR_NAV_HOLD					(HELPID_LEAR + 0x001e)
#define	HELPID_LEAR_LOC_GS_HOLD					(HELPID_LEAR + 0x001f)
#define	HELPID_LEAR_BACKCOURSE_HOLD				(HELPID_LEAR + 0x0020)
#define	HELPID_LEAR_AUTOPILOT_MASTER			(HELPID_LEAR + 0x0021)
#define	HELPID_LEAR_STROBES						(HELPID_LEAR + 0x0022)
#define	HELPID_LEAR_SPOILER						(HELPID_LEAR + 0x0023)
#define	HELPID_LEAR_TRIM						(HELPID_LEAR + 0x0024)
#define	HELPID_LEAR_LANDING_GEAR				(HELPID_LEAR + 0x0025)
#define	HELPID_LEAR_FLAP_INDICATOR				(HELPID_LEAR + 0x0026)
#define	HELPID_LEAR_COM_RADIO					(HELPID_LEAR + 0x0027)
#define	HELPID_LEAR_NAV1						(HELPID_LEAR + 0x0028)
#define	HELPID_LEAR_NAV2						(HELPID_LEAR + 0x0029)
#define	HELPID_LEAR_TRANSPONDER					(HELPID_LEAR + 0x002a)
#define	HELPID_LEAR_ADF_FREQ					(HELPID_LEAR + 0x002b)
#define	HELPID_LEAR_AILERON						(HELPID_LEAR + 0x002c)
#define	HELPID_LEAR_ELEVATOR					(HELPID_LEAR + 0x002d)
#define	HELPID_LEAR_RUDDER						(HELPID_LEAR + 0x002e)
#define	HELPID_LEAR_TEMPERATURE					(HELPID_LEAR + 0x002f)
#define	HELPID_LEAR_SKID_SLIP					(HELPID_LEAR + 0x0030)
#define	HELPID_LEAR_VOR1_INDICATOR				(HELPID_LEAR + 0x0031)
#define	HELPID_LEAR_VOR2_INDICATOR				(HELPID_LEAR + 0x0032)
#define	HELPID_LEAR_VERTICAL_SPEED				(HELPID_LEAR + 0x0033)
#define	HELPID_LEAR_NAV_LIGHTS					(HELPID_LEAR + 0x0034)
#define	HELPID_LEAR_DME1						(HELPID_LEAR + 0x0035)
#define	HELPID_LEAR_DME2						(HELPID_LEAR + 0x0036)
#define	HELPID_LEAR_HSI							(HELPID_LEAR + 0x0037)
#define HELPID_LEAR_MACH						(HELPID_LEAR + 0x0038)
#define HELPID_LEAR_PANEL_LIGHTS				(HELPID_LEAR + 0x0039)
#define HELPID_LEAR_LANDING_LIGHTS				(HELPID_LEAR + 0x003a)
#define HELPID_LEAR_WARNING_INDIC				(HELPID_LEAR + 0x003b)
#define	HELPID_LEAR_GLIDESLOPE					(HELPID_LEAR + 0x003c)
#define	HELPID_LEAR_VOR2_NEEDLE_TOGGLE			(HELPID_LEAR + 0x003d)
#define	HELPID_LEAR_ADF_NEEDLE_TOGGLE			(HELPID_LEAR + 0x00de)
#define	HELPID_LEAR_SPD							(HELPID_LEAR + 0x00df)
#define	HELPID_LEAR_IAS_MACH					(HELPID_LEAR + 0x00e0)
#define	HELPID_LEAR_MACH_INDICATOR				(HELPID_LEAR + 0x00e1)
#define	HELPID_LEAR_WARNING_ENUNCIATOR			(HELPID_LEAR + 0x00e2)
#define	HELPID_LEAR_ENUNCIATOR_TEST				(HELPID_LEAR + 0x00e3)

// sopwith strings (0x0200-0x02ff)
#define	HELPID_SOPWITH							HELPID_MIN + 0x0200

#define	HELPID_SOPWITH_ALT						(HELPID_SOPWITH + 0x0000)
#define	HELPID_SOPWITH_ASI						(HELPID_SOPWITH + 0x0001)
#define	HELPID_SOPWITH_COMPASS					(HELPID_SOPWITH + 0x0002)
#define	HELPID_SOPWITH_TURN						(HELPID_SOPWITH + 0x0003)
#define	HELPID_SOPWITH_FUEL						(HELPID_SOPWITH + 0x0004)
#define	HELPID_SOPWITH_OILP						(HELPID_SOPWITH + 0x0005)
#define	HELPID_SOPWITH_MAG						(HELPID_SOPWITH + 0x0006)
#define	HELPID_SOPWITH_RPM						(HELPID_SOPWITH + 0x0007)

// sailplane strings (0x0300-0x03ff)
#define	HELPID_SCHWEIZER						HELPID_MIN + 0x0300

#define	HELPID_SCHWEIZER_ALT					(HELPID_SCHWEIZER + 0x0000)
#define	HELPID_SCHWEIZER_ALT_SET				(HELPID_SCHWEIZER + 0x0001)
#define	HELPID_SCHWEIZER_ASI					(HELPID_SCHWEIZER + 0x0002)
#define	HELPID_SCHWEIZER_COMPASS				(HELPID_SCHWEIZER + 0x0003)
#define	HELPID_SCHWEIZER_SPOILERS				(HELPID_SCHWEIZER + 0x0004)
#define	HELPID_SCHWEIZER_COMM					(HELPID_SCHWEIZER + 0x0005)
#define	HELPID_SCHWEIZER_VSI					(HELPID_SCHWEIZER + 0x0006)
#define	HELPID_SCHWEIZER_MASTER_AVI				(HELPID_SCHWEIZER + 0x0007)

// b737 strings (0x0400-0x04ff)
#define	HELPID_B737								HELPID_MIN + 0x0400

#define	HELPID_B737_ALTIMETER					(HELPID_B737 + 0x0000)
#define	HELPID_B737_ALT_SET						(HELPID_B737 + 0x0001)
#define	HELPID_B737_AUTOPILOT					(HELPID_B737 + 0x0002)
#define	HELPID_B737_AUTOPILOT_MASTER			(HELPID_B737 + 0x0003)
#define	HELPID_B737_AUTOPILOT_HEADING			(HELPID_B737 + 0x0004)
#define	HELPID_B737_AUTOPILOT_ALT				(HELPID_B737 + 0x0005)
#define	HELPID_B737_AUTOPILOT_NAV				(HELPID_B737 + 0x0006)
#define	HELPID_B737_AUTOPILOT_LOC_GS			(HELPID_B737 + 0x0007)
#define	HELPID_B737_AUTOPILOT_BC				(HELPID_B737 + 0x0008)
#define	HELPID_B737_AIRSPEED					(HELPID_B737 + 0x0009)
#define	HELPID_B737_ATTITUDE					(HELPID_B737 + 0x000a)
#define	HELPID_B737_SLIP_SKID					(HELPID_B737 + 0x000b)
#define	HELPID_B737_CLOCK						(HELPID_B737 + 0x000c)
#define	HELPID_B737_SIM_RATE					(HELPID_B737 + 0x000d)
#define	HELPID_B737_ELAPSED_TIME				(HELPID_B737 + 0x000e)
#define	HELPID_B737_ENGINES						(HELPID_B737 + 0x000f)
#define	HELPID_B737_FAN_SPEED					(HELPID_B737 + 0x0010)
#define	HELPID_B737_EGT							(HELPID_B737 + 0x0011)
#define	HELPID_B737_TURBINE_SPEED				(HELPID_B737 + 0x0012)
#define	HELPID_B737_FUEL_FLOW					(HELPID_B737 + 0x0013)
#define	HELPID_B737_FLAPS						(HELPID_B737 + 0x0014)
#define	HELPID_B737_FUEL_QUANT					(HELPID_B737 + 0x0015)
#define	HELPID_B737_LANDING_GEAR				(HELPID_B737 + 0x0016)
#define	HELPID_B737_OIL							(HELPID_B737 + 0x0017)
#define	HELPID_B737_OIL_PRESSURE				(HELPID_B737 + 0x0018)
#define	HELPID_B737_OIL_TEMP					(HELPID_B737 + 0x0019)
#define	HELPID_B737_OIL_QUANT					(HELPID_B737 + 0x001a)
#define	HELPID_B737_HYDRAULIC					(HELPID_B737 + 0x001b)
#define	HELPID_B737_MARKER						(HELPID_B737 + 0x001c)
#define	HELPID_B737_STROBES						(HELPID_B737 + 0x001d)
#define	HELPID_B737_NAV_LIGHTS					(HELPID_B737 + 0x001e)
#define	HELPID_B737_ENGINE1_START				(HELPID_B737 + 0x001f)
#define	HELPID_B737_ENGINE2_START				(HELPID_B737 + 0x0020)
#define	HELPID_B737_COMM						(HELPID_B737 + 0x0021)
#define	HELPID_B737_NAV1						(HELPID_B737 + 0x0022)
#define	HELPID_B737_NAV2						(HELPID_B737 + 0x0023)
#define	HELPID_B737_ADF							(HELPID_B737 + 0x0024)
#define	HELPID_B737_TRANSPONDER					(HELPID_B737 + 0x0025)
#define	HELPID_B737_RMI							(HELPID_B737 + 0x0026)
#define	HELPID_B737_SPOILERS					(HELPID_B737 + 0x0027)
#define	HELPID_B737_THRUST_LEVERS				(HELPID_B737 + 0x0028)
#define	HELPID_B737_ELEVATOR_TRIM				(HELPID_B737 + 0x0029)
#define	HELPID_B737_VOR_INDICATOR				(HELPID_B737 + 0x002a)
#define	HELPID_B737_VSI							(HELPID_B737 + 0x002b)
#define	HELPID_B737_AUTOPILOT_WING_LEVELER		(HELPID_B737 + 0x002c)
#define	HELPID_B737_AUTOPILOT_YAW_DAMPER		(HELPID_B737 + 0x002d)
#define	HELPID_B737_AUTOPILOT_COURSE_SELECT		(HELPID_B737 + 0x002e)
#define	HELPID_B737_AUTOPILOT_HEADING_SELECT	(HELPID_B737 + 0x002f)
#define	HELPID_B737_AUTOPILOT_ALTITUDE_SELECT	(HELPID_B737 + 0x0030)
#define	HELPID_B737_TOTAL_AIR_TEMP				(HELPID_B737 + 0x0031)
#define	HELPID_B737_LANDING_GEAR_LEVER			(HELPID_B737 + 0x0032)
#define	HELPID_B737_VIBRATION					(HELPID_B737 + 0x0033)
#define	HELPID_B737_HYDRAULIC_QTY				(HELPID_B737 + 0x0034)
#define	HELPID_B737_DME1						(HELPID_B737 + 0x0035)
#define	HELPID_B737_DME2						(HELPID_B737 + 0x0036)
#define	HELPID_B737_AUTOPILOT_IAS_MACH_SELECT	(HELPID_B737 + 0x0037)
#define	HELPID_B737_TO_GA						(HELPID_B737 + 0x0038)
#define	HELPID_B737_AUTOTHROTTLE				(HELPID_B737 + 0x0039)
#define	HELPID_B737_REFERENCE_N1				(HELPID_B737 + 0x003a)
#define	HELPID_B737_N1_SET						(HELPID_B737 + 0x003b)
#define	HELPID_B737_CROSS_FEED					(HELPID_B737 + 0x003c)
#define	HELPID_B737_PITOT_HEAT					(HELPID_B737 + 0x003d)
#define	HELPID_B737_SPEED_HOLD					(HELPID_B737 + 0x003e)
#define	HELPID_B737_VERTICAL_SPEED_HOLD			(HELPID_B737 + 0x003f)
#define	HELPID_B737_SPEED_SELECT				(HELPID_B737 + 0x0040)
#define	HELPID_B737_VERTICAL_SPEED_SELECT		(HELPID_B737 + 0x0041)
#define	HELPID_B737_ZOOM						(HELPID_B737 + 0x0042)
#define	HELPID_B737_AUTO_THROTTLE_ARM			(HELPID_B737 + 0x0043)
#define HELPID_B737_TAKEOFF_POWER_ACTIVE		(HELPID_B737 + 0x0044)
#define	HELPID_B737_OPEN_RADIO_STACK			(HELPID_B737 + 0x0045)

// extra 300 strings (0x0500-0x05ff)
#define	HELPID_EXTRA							HELPID_MIN + 0x0500

#define	HELPID_EXTR_ADF_INDICATOR				(HELPID_EXTRA + 0x0000)
#define	HELPID_EXTR_ADF_SET						(HELPID_EXTRA + 0x0001)
#define	HELPID_EXTR_ALTIMETER					(HELPID_EXTRA + 0x0002)
#define	HELPID_EXTR_ALTIMETER_SET				(HELPID_EXTRA + 0x0003)
#define	HELPID_EXTR_AIRSPEED					(HELPID_EXTRA + 0x0004)
#define	HELPID_EXTR_ATTITUDE_INDICATOR			(HELPID_EXTRA + 0x0005)
#define	HELPID_EXTR_TURN_NEEDLE					(HELPID_EXTRA + 0x0006)
#define	HELPID_EXTR_SLIP_SKID					(HELPID_EXTRA + 0x0007)
#define	HELPID_EXTR_ENGINE_CONTROLS				(HELPID_EXTRA + 0x0008)
#define	HELPID_EXTR_THROTTLE					(HELPID_EXTRA + 0x0009)
#define	HELPID_EXTR_PROP						(HELPID_EXTRA + 0x000a)
#define	HELPID_EXTR_MIXTURE						(HELPID_EXTRA + 0x000b)
#define	HELPID_EXTR_CLOCK						(HELPID_EXTRA + 0x000c)
#define	HELPID_EXTR_SIM_RATE					(HELPID_EXTRA + 0x000d)
#define	HELPID_EXTR_COMPASS						(HELPID_EXTRA + 0x000e)
#define	HELPID_EXTR_MASTER_SWITCH				(HELPID_EXTRA + 0x000f)
#define	HELPID_EXTR_PANEL_LIGHTS				(HELPID_EXTRA + 0x0010)
#define	HELPID_EXTR_STROBE_LIGHTS				(HELPID_EXTRA + 0x0011)
#define	HELPID_EXTR_RADIO_MASTER				(HELPID_EXTRA + 0x0012)
#define	HELPID_EXTR_SMOKE						(HELPID_EXTRA + 0x0013)
#define	HELPID_EXTR_ACRO_TANK					(HELPID_EXTRA + 0x0014)
#define	HELPID_EXTR_MAIN_TANK					(HELPID_EXTRA + 0x0015)
#define	HELPID_EXTR_FUEL_FLOW					(HELPID_EXTRA + 0x0016)
#define	HELPID_EXTR_EGT							(HELPID_EXTRA + 0x0017)
#define	HELPID_EXTR_AMPS						(HELPID_EXTRA + 0x0018)
#define	HELPID_EXTR_STARTER						(HELPID_EXTRA + 0x0019)
#define	HELPID_EXTR_HEADING_INDICATOR			(HELPID_EXTRA + 0x001a)
#define	HELPID_EXTR_HEADING_SET					(HELPID_EXTRA + 0x001b)
#define	HELPID_EXTR_G_METER						(HELPID_EXTRA + 0x001c)
#define	HELPID_EXTR_RADIOS						(HELPID_EXTRA + 0x001d)
#define	HELPID_EXTR_COMM						(HELPID_EXTRA + 0x001e)
#define	HELPID_EXTR_NAV							(HELPID_EXTRA + 0x001f)
#define	HELPID_EXTR_TRANSPONDER					(HELPID_EXTRA + 0x0020)
#define	HELPID_EXTR_ADF							(HELPID_EXTRA + 0x0021)
#define	HELPID_EXTR_VSI							(HELPID_EXTRA + 0x0022)
#define	HELPID_EXTR_RPM							(HELPID_EXTRA + 0x0023)
#define	HELPID_EXTR_MP							(HELPID_EXTRA + 0x0024)
#define	HELPID_EXTR_OIL_TEMP					(HELPID_EXTRA + 0x0025)
#define	HELPID_EXTR_OIL_PRESSURE				(HELPID_EXTRA + 0x0026)
#define	HELPID_EXTR_G_METER_RESET				(HELPID_EXTRA + 0x0027)
#define	HELPID_EXTR_VOR1						(HELPID_EXTRA + 0x0028)
#define	HELPID_EXTR_OBI1						(HELPID_EXTRA + 0x0029)
#define	HELPID_EXTR_ARESTI_DIAGRAM				(HELPID_EXTRA + 0x002a)
#define	HELPID_EXTR_DME							(HELPID_EXTRA + 0x002b)

// Bell 206B strings (0x0600-0x06ff)
#define	HELPID_BELL								HELPID_MIN + 0x0600

#define	HELPID_BELL_OIL_PSI						(HELPID_BELL + 0x0000)
#define	HELPID_BELL_OIL_TEMP					(HELPID_BELL + 0x0001)
#define	HELPID_BELL_XMISSION_PSI				(HELPID_BELL + 0x0002)
#define	HELPID_BELL_XMISSION_TEMP				(HELPID_BELL + 0x0003)
#define	HELPID_BELL_FUEL_QTY					(HELPID_BELL + 0x0004)
#define	HELPID_BELL_GEN_LOAD					(HELPID_BELL + 0x0005)
#define	HELPID_BELL_FUEL_PSI					(HELPID_BELL + 0x0006)
#define	HELPID_BELL_TORQUE						(HELPID_BELL + 0x0007)
#define	HELPID_BELL_TURBINE_TEMP				(HELPID_BELL + 0x0008)
#define	HELPID_BELL_GAS_PRODUCER				(HELPID_BELL + 0x0009)
#define	HELPID_BELL_CLOCK						(HELPID_BELL + 0x000a)
#define	HELPID_BELL_AIRSPEED					(HELPID_BELL + 0x000b)
#define	HELPID_BELL_ROTOR_TURBINE				(HELPID_BELL + 0x000c)
#define	HELPID_BELL_ADF							(HELPID_BELL + 0x000d)
#define	HELPID_BELL_ADF_SETTING					(HELPID_BELL + 0x000e)
#define	HELPID_BELL_ATTITUDE					(HELPID_BELL + 0x000f)
#define	HELPID_BELL_HSI							(HELPID_BELL + 0x0010)
#define	HELPID_BELL_VOR2						(HELPID_BELL + 0x0011)
#define	HELPID_BELL_ALTIMETER					(HELPID_BELL + 0x0012)
#define	HELPID_BELL_KOHLSMAN					(HELPID_BELL + 0x0013)
#define	HELPID_BELL_VSI							(HELPID_BELL + 0x0014)
#define	HELPID_BELL_TURN_INDICATOR				(HELPID_BELL + 0x0015)
#define	HELPID_BELL_CYCLIC_FA					(HELPID_BELL + 0x0016)
#define	HELPID_BELL_CYCLIC_LR					(HELPID_BELL + 0x0017)
#define	HELPID_BELL_ANTI_TORQUE_ROTOR			(HELPID_BELL + 0x0018)

// Bendix/King radios (0x0700-0x07ff)
#define	HELPID_BK								HELPID_MIN + 0x0700

#define	HELPID_BK_NAV1							(HELPID_BK + 0x0000)
#define	HELPID_BK_COMM1							(HELPID_BK + 0x0001)
#define	HELPID_BK_NAV2							(HELPID_BK + 0x0002)
#define	HELPID_BK_COMM2							(HELPID_BK + 0x0003)
#define	HELPID_BK_DME							(HELPID_BK + 0x0004)
#define	HELPID_BK_DME_KT						(HELPID_BK + 0x0005)
#define	HELPID_BK_DME_NM						(HELPID_BK + 0x0006)
#define	HELPID_BK_DME_MIN						(HELPID_BK + 0x0007)
#define	HELPID_BK_DME_N1_N2_SELECT				(HELPID_BK + 0x0008)
#define	HELPID_BK_ADF_RADIO						(HELPID_BK + 0x0009)
#define	HELPID_BK_TRANSPONDER					(HELPID_BK + 0x000a)
#define	HELPID_BK_RADIOS_OPEN					(HELPID_BK + 0x000b)
#define	HELPID_BK_AP_RADIO						(HELPID_BK + 0x000c)


//
// Key Accelerator Event IDs
//
#define KEY_ID_MIN						0x00010000

#define	KEY_NULL						(KEY_ID_MIN + 0)
#define KEY_DEMO_STOP		  			(KEY_ID_MIN + 1)
#define KEY_REPLAY_STOP		  			(KEY_ID_MIN + 1)	// ESCAPE
#define KEY_SELECT_1					(KEY_ID_MIN + 2)
#define KEY_SELECT_2					(KEY_ID_MIN + 3)
#define KEY_SELECT_3					(KEY_ID_MIN + 4)
#define KEY_SELECT_4					(KEY_ID_MIN + 5)
#define KEY_DEMO_RECORD_1_SEC			(KEY_ID_MIN + 7)
#define KEY_DEMO_RECORD_5_SEC			(KEY_ID_MIN + 8)
#define KEY_MINUS						(KEY_ID_MIN + 12)
#define KEY_PLUS						(KEY_ID_MIN + 13)
#define KEY_ZOOM_1X						(KEY_ID_MIN + 14)
#define KEY_PANEL_SELECT_1				(KEY_ID_MIN + 15)
#define KEY_SOUND_TOGGLE				(KEY_ID_MIN + 16)
#define KEY_FULL_WINDOW_TOGGLE			(KEY_ID_MIN + 17)
#define KEY_ENGINE						(KEY_ID_MIN + 18)
#define KEY_SIM_RATE					(KEY_ID_MIN + 19)
#define KEY_XPNDR						(KEY_ID_MIN + 20)
#define KEY_SLEW_TOGGLE					(KEY_ID_MIN + 21)
#define KEY_EGT							(KEY_ID_MIN + 22)
#define KEY_SMOKE_TOGGLE				(KEY_ID_MIN + 23)
#define KEY_STROBES_TOGGLE				(KEY_ID_MIN + 24)
#define KEY_PAUSE_TOGGLE				(KEY_ID_MIN + 25)
#define KEY_ATC							(KEY_ID_MIN + 28)
#define KEY_ADF							(KEY_ID_MIN + 30)
#define KEY_VIEW_MODE					(KEY_ID_MIN + 31)
#define KEY_HEADING_GYRO_SET			(KEY_ID_MIN + 32)
#define KEY_DME							(KEY_ID_MIN + 33)
#define KEY_GEAR_TOGGLE					(KEY_ID_MIN + 34)
#define KEY_ANTI_ICE_TOGGLE				(KEY_ID_MIN + 35)
#define KEY_JET_STARTER					(KEY_ID_MIN + 36)
#define KEY_JOYSTICK_CALIBRATE			(KEY_ID_MIN + 37)
#define KEY_ALL_LIGHTS_TOGGLE			(KEY_ID_MIN + 38)
#define KEY_SITUATION_SAVE				(KEY_ID_MIN + 39)
#define KEY_VIEW_WINDOW_TO_FRONT		(KEY_ID_MIN + 40)
#define KEY_DEMO_RECORD_STOP			(KEY_ID_MIN + 43)
#define KEY_ANALYSIS_MANEUVER_STOP		(KEY_ID_MIN + 43)
#define KEY_AP_MASTER					(KEY_ID_MIN + 44)
#define KEY_LANDME_TOGGLE				(KEY_ID_MIN + 45)
#define KEY_COM_RADIO					(KEY_ID_MIN + 46)
#define KEY_VOR_OBS						(KEY_ID_MIN + 47)
#define KEY_BAROMETRIC					(KEY_ID_MIN + 48)
#define KEY_NAV_RADIO					(KEY_ID_MIN + 49)
#define KEY_MAGNETO						(KEY_ID_MIN + 50)
#define KEY_DEMO_RECORD_MESSAGE			(KEY_ID_MIN + 51)
#define KEY_BRAKES						(KEY_ID_MIN + 52)
#define KEY_SPOILERS_TOGGLE				(KEY_ID_MIN + 53)
#define KEY_SITUATION_RESET				(KEY_ID_MIN + 55)
#define KEY_FLAPS_UP					(KEY_ID_MIN + 59)
#define KEY_THROTTLE_FULL				(KEY_ID_MIN + 60)
#define KEY_FLAPS_1						(KEY_ID_MIN + 61)
#define KEY_THROTTLE_INCR				(KEY_ID_MIN + 62)
#define KEY_FLAPS_2						(KEY_ID_MIN + 63)
#define KEY_THROTTLE_INCR_SMALL			(KEY_ID_MIN + 64)
#define KEY_FLAPS_3						(KEY_ID_MIN + 65)
#define KEY_THROTTLE_DECR				(KEY_ID_MIN + 66)
#define KEY_FLAPS_4						(KEY_ID_MIN + 67)
#define KEY_FLAPS_DOWN					(KEY_ID_MIN + 67)		// KEY_FLAPS_4 synonym
#define KEY_THROTTLE_CUT				(KEY_ID_MIN + 68)
#define KEY_VIEW						(KEY_ID_MIN + 70)
#define KEY_NUMPAD7						(KEY_ID_MIN + 71)
#define KEY_NUMPAD8						(KEY_ID_MIN + 72)
#define KEY_NUMPAD9						(KEY_ID_MIN + 73)
#define KEY_NUMPAD4						(KEY_ID_MIN + 75)
#define KEY_NUMPAD5						(KEY_ID_MIN + 76)
#define KEY_NUMPAD6						(KEY_ID_MIN + 77)
#define KEY_NUMPAD1						(KEY_ID_MIN + 79)
#define KEY_NUMPAD2						(KEY_ID_MIN + 80)
#define KEY_NUMPAD3						(KEY_ID_MIN + 81)
#define KEY_MOUSE_AS_YOKE_TOGGLE		(KEY_ID_MIN + 83)
#define KEY_SLEW_ALTIT_UP_FAST			(KEY_ID_MIN + 84)
#define KEY_SLEW_ALTIT_UP_SLOW			(KEY_ID_MIN + 85)
#define KEY_SLEW_ALTIT_FREEZE			(KEY_ID_MIN + 86)
#define KEY_SLEW_ALTIT_DN_SLOW			(KEY_ID_MIN + 87)
#define KEY_SLEW_ALTIT_DN_FAST			(KEY_ID_MIN + 88)
#define KEY_SLEW_ALTIT_PLUS				(KEY_ID_MIN + 89)
#define KEY_SLEW_ALTIT_MINUS			(KEY_ID_MIN + 90)
#define KEY_SLEW_PITCH_DN_FAST			(KEY_ID_MIN + 91)
#define KEY_SLEW_PITCH_DN_SLOW			(KEY_ID_MIN + 92)
#define KEY_SLEW_PITCH_FREEZE			(KEY_ID_MIN + 93)
#define KEY_SLEW_PITCH_UP_SLOW			(KEY_ID_MIN + 94)
#define KEY_SLEW_PITCH_UP_FAST			(KEY_ID_MIN + 95)
#define KEY_SLEW_PITCH_PLUS				(KEY_ID_MIN + 96)
#define KEY_SLEW_PITCH_MINUS			(KEY_ID_MIN + 97)
#define KEY_MAGNETO_DECR				(KEY_ID_MIN + 98)
#define KEY_MAGNETO_INCR				(KEY_ID_MIN + 99)
#define KEY_COM_RADIO_WHOLE_DEC			(KEY_ID_MIN + 100)
#define KEY_COM_RADIO_WHOLE_INC			(KEY_ID_MIN + 101)
#define KEY_COM_RADIO_FRACT_DEC			(KEY_ID_MIN + 102)
#define KEY_COM_RADIO_FRACT_INC			(KEY_ID_MIN + 103)
#define KEY_NAV1_RADIO_WHOLE_DEC		(KEY_ID_MIN + 104)
#define KEY_NAV1_RADIO_WHOLE_INC		(KEY_ID_MIN + 105)
#define KEY_NAV1_RADIO_FRACT_DEC		(KEY_ID_MIN + 106)
#define KEY_NAV1_RADIO_FRACT_INC		(KEY_ID_MIN + 107)
#define KEY_NAV2_RADIO_WHOLE_DEC		(KEY_ID_MIN + 108)
#define KEY_NAV2_RADIO_WHOLE_INC		(KEY_ID_MIN + 109)
#define KEY_NAV2_RADIO_FRACT_DEC		(KEY_ID_MIN + 110)
#define KEY_NAV2_RADIO_FRACT_INC		(KEY_ID_MIN + 111)
#define KEY_ADF_100_INC					(KEY_ID_MIN + 112)
#define KEY_ADF_10_INC					(KEY_ID_MIN + 113)
#define KEY_ADF_1_INC					(KEY_ID_MIN + 114)
#define KEY_XPNDR_1000_INC				(KEY_ID_MIN + 115)
#define KEY_XPNDR_100_INC				(KEY_ID_MIN + 116)
#define KEY_XPNDR_10_INC				(KEY_ID_MIN + 117)
#define KEY_XPNDR_1_INC					(KEY_ID_MIN + 118)
#define KEY_ZOOM_IN						(KEY_ID_MIN + 119)
#define KEY_ZOOM_OUT					(KEY_ID_MIN + 120)
#define KEY_CLOCK_HOURS_DEC				(KEY_ID_MIN + 121)
#define KEY_CLOCK_HOURS_INC				(KEY_ID_MIN + 122)
#define KEY_CLOCK_MINUTES_DEC			(KEY_ID_MIN + 123)
#define KEY_CLOCK_MINUTES_INC			(KEY_ID_MIN + 124)
#define KEY_CLOCK_SECONDS_ZERO			(KEY_ID_MIN + 125)
#define KEY_VOR1_OBI_DEC				(KEY_ID_MIN + 126)
#define KEY_VOR1_OBI_INC				(KEY_ID_MIN + 127)
#define KEY_VOR2_OBI_DEC				(KEY_ID_MIN + 128)
#define KEY_VOR2_OBI_INC				(KEY_ID_MIN + 129)
#define KEY_ADF_100_DEC					(KEY_ID_MIN + 130)
#define KEY_ADF_10_DEC					(KEY_ID_MIN + 131)
#define KEY_ADF_1_DEC					(KEY_ID_MIN + 132)
#define KEY_AP_MASTER_ALT				(KEY_ID_MIN + 133)
#define KEY_MAP_ZOOM_FINE_IN			(KEY_ID_MIN + 134)
#define KEY_PAN_LEFT					(KEY_ID_MIN + 135)
#define KEY_PAN_RIGHT					(KEY_ID_MIN + 136)
#define KEY_MAP_ZOOM_FINE_OUT			(KEY_ID_MIN + 137)
#define KEY_VIEW_FORWARD				(KEY_ID_MIN + 138)
#define KEY_VIEW_FORWARD_RIGHT			(KEY_ID_MIN + 139)
#define KEY_VIEW_RIGHT					(KEY_ID_MIN + 140)
#define KEY_VIEW_REAR_RIGHT				(KEY_ID_MIN + 141)
#define KEY_VIEW_REAR					(KEY_ID_MIN + 142)
#define KEY_VIEW_REAR_LEFT				(KEY_ID_MIN + 143)
#define KEY_VIEW_LEFT					(KEY_ID_MIN + 144)
#define KEY_VIEW_FORWARD_LEFT			(KEY_ID_MIN + 145)
#define KEY_VIEW_DOWN					(KEY_ID_MIN + 146)
#define KEY_ELEVATOR_DOWN				(KEY_ID_MIN + 147)
#define KEY_ELEVATOR_UP					(KEY_ID_MIN + 148)
#define KEY_AILERON_LEFT				(KEY_ID_MIN + 149)
#define KEY_AILERON_CENTER				(KEY_ID_MIN + 150)
#define KEY_AILERON_RIGHT				(KEY_ID_MIN + 151)
#define KEY_RUDDER_LEFT					(KEY_ID_MIN + 152)
#define KEY_RUDDER_CENTER				(KEY_ID_MIN + 153)
#define KEY_RUDDER_RIGHT				(KEY_ID_MIN + 154)
#define KEY_VIEW1_MODE_SET				(KEY_ID_MIN + 155)
#define KEY_SOUND_SET					(KEY_ID_MIN + 156)
#define KEY_VIEW1_DIRECTION_SET			(KEY_ID_MIN + 157)
#define KEY_ELEVATOR_SET				(KEY_ID_MIN + 158)
#define KEY_AILERON_SET					(KEY_ID_MIN + 159)
#define KEY_RUDDER_SET					(KEY_ID_MIN + 160)
#define KEY_THROTTLE_SET				(KEY_ID_MIN + 161)
#define KEY_FLAPS_SET					(KEY_ID_MIN + 162)
#define KEY_GEAR_SET					(KEY_ID_MIN + 164)
#define KEY_VIEW1_ZOOM_SET				(KEY_ID_MIN + 165)
#define KEY_AXIS_IND_SET				(KEY_ID_MIN + 166)
#define KEY_VIEW1_WINDOW_SET			(KEY_ID_MIN + 167)
#define KEY_VIEW2_WINDOW_SET			(KEY_ID_MIN + 168)
#define KEY_MAP_WINDOW_SET				(KEY_ID_MIN + 169)
#define KEY_ELEVATOR_TRIM_SET			(KEY_ID_MIN + 170)
#define KEY_COM_RADIO_SET				(KEY_ID_MIN + 171)
#define KEY_NAV1_RADIO_SET				(KEY_ID_MIN + 172)
#define KEY_NAV2_RADIO_SET				(KEY_ID_MIN + 173)
#define KEY_VIEW2_MODE_SET				(KEY_ID_MIN + 174)
#define KEY_VIEW2_DIRECTION_SET			(KEY_ID_MIN + 175)
#define KEY_VIEW2_ZOOM_SET				(KEY_ID_MIN + 176)
#define KEY_MAP_ZOOM_SET				(KEY_ID_MIN + 177)
#define KEY_ADF_SET						(KEY_ID_MIN + 178)
#define KEY_XPNDR_SET					(KEY_ID_MIN + 179)
#define KEY_VOR1_SET					(KEY_ID_MIN + 180)
#define KEY_VOR2_SET					(KEY_ID_MIN + 181)
#define KEY_ZOOM_MINUS					(KEY_ID_MIN + 182)
#define KEY_ZOOM_PLUS					(KEY_ID_MIN + 183)
#define KEY_BRAKES_LEFT					(KEY_ID_MIN + 184)
#define KEY_BRAKES_RIGHT				(KEY_ID_MIN + 185)
#define KEY_AP_ATT_HOLD					(KEY_ID_MIN + 186)
#define KEY_AP_LOC_HOLD					(KEY_ID_MIN + 187)
#define KEY_AP_APR_HOLD					(KEY_ID_MIN + 188)
#define KEY_AP_HDG_HOLD					(KEY_ID_MIN + 189)
#define KEY_AP_ALT_HOLD					(KEY_ID_MIN + 190)
#define KEY_AP_WING_LEVELER				(KEY_ID_MIN + 191)
#define KEY_AP_BC_HOLD					(KEY_ID_MIN + 192)
#define KEY_AP_NAV1_HOLD				(KEY_ID_MIN + 193)
#define KEY_SLEW_OFF					(KEY_ID_MIN + 194)
#define KEY_SLEW_ON						(KEY_ID_MIN + 195)
#define KEY_EXIT						(KEY_ID_MIN + 196)
#define KEY_ABORT						(KEY_ID_MIN + 197)
#define KEY_PAN_UP						(KEY_ID_MIN + 198)
#define KEY_PAN_DOWN					(KEY_ID_MIN + 199)
#define KEY_READOUTS_SLEW				(KEY_ID_MIN + 200)
#define KEY_READOUTS_FLIGHT				(KEY_ID_MIN + 201)
#define KEY_SLEW_BANK_MINUS				(KEY_ID_MIN + 202)
#define KEY_SLEW_AHEAD_PLUS				(KEY_ID_MIN + 203)
#define KEY_SLEW_BANK_PLUS				(KEY_ID_MIN + 204)
#define KEY_SLEW_LEFT					(KEY_ID_MIN + 205)
#define KEY_SLEW_FREEZE					(KEY_ID_MIN + 206)
#define KEY_SLEW_RIGHT					(KEY_ID_MIN + 207)
#define KEY_SLEW_HEADING_MINUS			(KEY_ID_MIN + 208)
#define KEY_SLEW_AHEAD_MINUS			(KEY_ID_MIN + 209)
#define KEY_SLEW_HEADING_PLUS			(KEY_ID_MIN + 210)
#define KEY_PANEL_SELECT_2				(KEY_ID_MIN + 211)
#define KEY_PANEL_TOGGLE				(KEY_ID_MIN + 212)
#define KEY_VIEW_MODE_REV				(KEY_ID_MIN + 213)
#define KEY_PANEL_LIGHTS_TOGGLE			(KEY_ID_MIN + 214)
#define KEY_LANDING_LIGHTS_TOGGLE		(KEY_ID_MIN + 215)
#define KEY_PARKING_BRAKES				(KEY_ID_MIN + 216)
#define KEY_ZOOM_IN_FINE				(KEY_ID_MIN + 218)
#define KEY_ZOOM_OUT_FINE				(KEY_ID_MIN + 219)
#define KEY_MINUS_SHIFT					(KEY_ID_MIN + 220)
#define KEY_PLUS_SHIFT					(KEY_ID_MIN + 221)
#define	KEY_FLAPS_INCR					(KEY_ID_MIN + 222)
#define	KEY_FLAPS_DECR					(KEY_ID_MIN + 223)
#define	KEY_FLAPS_DETENTS_SET			(KEY_ID_MIN + 224)
#define KEY_AXIS_ELEVATOR_SET			(KEY_ID_MIN + 226)
#define KEY_AXIS_AILERONS_SET			(KEY_ID_MIN + 227)
#define KEY_AXIS_RUDDER_SET				(KEY_ID_MIN + 228)
#define KEY_AXIS_THROTTLE_SET			(KEY_ID_MIN + 229)
#define KEY_AXIS_ELEV_TRIM_SET			(KEY_ID_MIN + 230)
#define KEY_PROP_PITCH_SET				(KEY_ID_MIN + 231)
#define KEY_PROP_PITCH_LO				(KEY_ID_MIN + 232)
#define KEY_PROP_PITCH_INCR				(KEY_ID_MIN + 233)
#define KEY_PROP_PITCH_INCR_SMALL		(KEY_ID_MIN + 234)
#define KEY_PROP_PITCH_DECR				(KEY_ID_MIN + 235)
#define KEY_PROP_PITCH_HI				(KEY_ID_MIN + 236)
#define KEY_MIXTURE_SET					(KEY_ID_MIN + 237)
#define KEY_MIXTURE_RICH				(KEY_ID_MIN + 238)
#define KEY_MIXTURE_INCR				(KEY_ID_MIN + 239)
#define KEY_MIXTURE_INCR_SMALL			(KEY_ID_MIN + 240)
#define KEY_MIXTURE_DECR				(KEY_ID_MIN + 241)
#define KEY_MIXTURE_LEAN				(KEY_ID_MIN + 242)
#define KEY_MOUSE_AS_YOKE_OFF			(KEY_ID_MIN + 246)
#define KEY_MOUSE_AS_YOKE_ON			(KEY_ID_MIN + 247)
#define	KEY_MOUSE_AS_YOKE_SUSPEND		(KEY_ID_MIN + 248)
#define	KEY_MOUSE_AS_YOKE_RESUME		(KEY_ID_MIN + 249)
#define KEY_SPOILERS_SET				(KEY_ID_MIN + 250)
#define KEY_DME1_TOGGLE					(KEY_ID_MIN + 251)
#define KEY_DME2_TOGGLE					(KEY_ID_MIN + 252)
#define KEY_SIM_RATE_INCR				(KEY_ID_MIN + 253)
#define KEY_SIM_RATE_DECR				(KEY_ID_MIN + 254)
#define KEY_AUTOPILOT_OFF				(KEY_ID_MIN + 255)
#define KEY_AUTOPILOT_ON				(KEY_ID_MIN + 256)
#define KEY_YAW_DAMPER_TOGGLE			(KEY_ID_MIN + 257)
#define	KEY_PAUSE_ON					(KEY_ID_MIN + 258)
#define	KEY_PAUSE_OFF					(KEY_ID_MIN + 259)
#define	KEY_SLEW_RESET					(KEY_ID_MIN + 260)
#define	KEY_AP_PANEL_HEADING_HOLD		(KEY_ID_MIN + 262)
#define	KEY_AP_PANEL_ALTITUDE_HOLD		(KEY_ID_MIN + 263)
#define	KEY_CHVPP_LEFT_HAT_UP			(KEY_ID_MIN + 264)
#define KEY_CHVPP_LEFT_HAT_DOWN			(KEY_ID_MIN + 265)
#define	KEY_CHVPP_AP_ALT_WING			(KEY_ID_MIN + 266)
#define	KEY_CENTER_NT361_CHECK			(KEY_ID_MIN + 267)				
#define KEY_AP_ATT_HOLD_ON				(KEY_ID_MIN + 268)
#define KEY_AP_LOC_HOLD_ON				(KEY_ID_MIN + 269)
#define KEY_AP_APR_HOLD_ON				(KEY_ID_MIN + 270)
#define KEY_AP_HDG_HOLD_ON				(KEY_ID_MIN + 271)
#define KEY_AP_ALT_HOLD_ON				(KEY_ID_MIN + 272)
#define KEY_AP_WING_LEVELER_ON			(KEY_ID_MIN + 273)
#define KEY_AP_BC_HOLD_ON				(KEY_ID_MIN + 274)
#define KEY_AP_NAV1_HOLD_ON				(KEY_ID_MIN + 275)
#define KEY_AP_ATT_HOLD_OFF				(KEY_ID_MIN + 276)
#define KEY_AP_LOC_HOLD_OFF				(KEY_ID_MIN + 277)
#define KEY_AP_APR_HOLD_OFF				(KEY_ID_MIN + 278)
#define KEY_AP_HDG_HOLD_OFF				(KEY_ID_MIN + 279)
#define KEY_AP_ALT_HOLD_OFF				(KEY_ID_MIN + 280)
#define KEY_AP_WING_LEVELER_OFF			(KEY_ID_MIN + 281)
#define KEY_AP_BC_HOLD_OFF				(KEY_ID_MIN + 282)
#define KEY_AP_NAV1_HOLD_OFF			(KEY_ID_MIN + 283)
#define KEY_THROTTLE1_SET				(KEY_ID_MIN + 284)
#define KEY_THROTTLE2_SET				(KEY_ID_MIN + 285)
#define KEY_THROTTLE3_SET				(KEY_ID_MIN + 286)
#define KEY_THROTTLE4_SET				(KEY_ID_MIN + 287)
#define	KEY_CLOSE_VIEW					(KEY_ID_MIN + 288)
#define	KEY_NEW_VIEW					(KEY_ID_MIN + 289)
#define	KEY_NEW_MAP						(KEY_ID_MIN + 290)
#define	KEY_NEXT_VIEW					(KEY_ID_MIN + 291)
#define	KEY_PREV_VIEW					(KEY_ID_MIN + 292)
#define	KEY_VIEW_TYPE					(KEY_ID_MIN + 293)
#define	KEY_VIEW_TYPE_REV				(KEY_ID_MIN + 294)
#define	KEY_VIEW_TYPE_SET				(KEY_ID_MIN + 295)
#define	KEY_RADIO_VOR1_IDENT_DISABLE	(KEY_ID_MIN + 296)
#define	KEY_RADIO_VOR2_IDENT_DISABLE	(KEY_ID_MIN + 297)
#define	KEY_RADIO_DME1_IDENT_DISABLE	(KEY_ID_MIN + 298)
#define	KEY_RADIO_DME2_IDENT_DISABLE	(KEY_ID_MIN + 299)
#define	KEY_RADIO_ADF_IDENT_DISABLE		(KEY_ID_MIN + 300)
#define	KEY_RADIO_VOR1_IDENT_ENABLE		(KEY_ID_MIN + 301)
#define	KEY_RADIO_VOR2_IDENT_ENABLE		(KEY_ID_MIN + 302)
#define	KEY_RADIO_DME1_IDENT_ENABLE		(KEY_ID_MIN + 303)
#define	KEY_RADIO_DME2_IDENT_ENABLE		(KEY_ID_MIN + 304)
#define	KEY_RADIO_ADF_IDENT_ENABLE		(KEY_ID_MIN + 305)
#define	KEY_RADIO_VOR1_IDENT_TOGGLE		(KEY_ID_MIN + 306)
#define	KEY_RADIO_VOR2_IDENT_TOGGLE		(KEY_ID_MIN + 307)
#define	KEY_RADIO_DME1_IDENT_TOGGLE		(KEY_ID_MIN + 308)
#define	KEY_RADIO_DME2_IDENT_TOGGLE		(KEY_ID_MIN + 309)
#define	KEY_RADIO_ADF_IDENT_TOGGLE		(KEY_ID_MIN + 310)
#define	KEY_RADIO_VOR1_IDENT_SET		(KEY_ID_MIN + 311)
#define	KEY_RADIO_VOR2_IDENT_SET		(KEY_ID_MIN + 312)
#define	KEY_RADIO_DME1_IDENT_SET		(KEY_ID_MIN + 313)
#define	KEY_RADIO_DME2_IDENT_SET		(KEY_ID_MIN + 314)
#define	KEY_RADIO_ADF_IDENT_SET			(KEY_ID_MIN + 315)
#define KEY_GEAR_PUMP					(KEY_ID_MIN + 316)
#define KEY_SPOILERS_ARM_TOGGLE			(KEY_ID_MIN + 317)
#define KEY_PAN_LEFT_UP					(KEY_ID_MIN + 318)
#define KEY_PAN_LEFT_DOWN				(KEY_ID_MIN + 319)
#define KEY_PAN_RIGHT_UP				(KEY_ID_MIN + 320)
#define KEY_PAN_RIGHT_DOWN				(KEY_ID_MIN + 321)
#define KEY_PITOT_HEAT_TOGGLE			(KEY_ID_MIN + 322)
#define KEY_AP_AIRSPEED_HOLD 			(KEY_ID_MIN + 323)
#define KEY_AUTO_THROTTLE_ARM           (KEY_ID_MIN + 324)
#define KEY_AUTO_THROTTLE_TO_GA         (KEY_ID_MIN + 325)
#define KEY_LANDING_LIGHT_UP			(KEY_ID_MIN + 326)
#define KEY_LANDING_LIGHT_DOWN			(KEY_ID_MIN + 327)
#define KEY_LANDING_LIGHT_LEFT			(KEY_ID_MIN + 328)
#define KEY_LANDING_LIGHT_RIGHT			(KEY_ID_MIN + 329)
#define KEY_LANDING_LIGHT_HOME			(KEY_ID_MIN + 330)
#define KEY_AXIS_SLEW_AHEAD_SET			(KEY_ID_MIN + 331)
#define KEY_AXIS_SLEW_SIDEWAYS_SET		(KEY_ID_MIN + 332)
#define KEY_AXIS_SLEW_HEADING_SET		(KEY_ID_MIN + 333)
#define KEY_AXIS_SLEW_ALT_SET			(KEY_ID_MIN + 334)
#define KEY_AXIS_SLEW_BANK_SET			(KEY_ID_MIN + 335)
#define KEY_AXIS_SLEW_PITCH_SET			(KEY_ID_MIN + 336)
#define KEY_PAN_TILT_LEFT				(KEY_ID_MIN + 337)
#define KEY_PAN_TILT_RIGHT				(KEY_ID_MIN + 338)
#define KEY_PAN_RESET					(KEY_ID_MIN + 339)
#define KEY_CHECKLISTS					(KEY_ID_MIN + 340)
#define	KEY_GYRO_DRIFT_INC				(KEY_ID_MIN + 341)
#define	KEY_GYRO_DRIFT_DEC				(KEY_ID_MIN + 342)
#define	KEY_HEADING_BUG_INC				(KEY_ID_MIN + 343)
#define	KEY_HEADING_BUG_DEC				(KEY_ID_MIN + 344)
#define	KEY_ADF_CARD_INC				(KEY_ID_MIN + 345)
#define	KEY_ADF_CARD_DEC				(KEY_ID_MIN + 346)
#define	KEY_KOHLSMAN_INC				(KEY_ID_MIN + 347)
#define	KEY_KOHLSMAN_DEC				(KEY_ID_MIN + 348)
#define	KEY_TRUE_AIRSPEED_CALIBRATE_INC	(KEY_ID_MIN + 349)
#define	KEY_TRUE_AIRSPEED_CALIBRATE_DEC	(KEY_ID_MIN + 350)
#define	KEY_CROSS_FEED_OFF				(KEY_ID_MIN + 351)
#define	KEY_CROSS_FEED_LEFT_TO_RIGHT	(KEY_ID_MIN + 352)
#define	KEY_CROSS_FEED_RIGHT_TO_LEFT	(KEY_ID_MIN + 353)
#define	KEY_AP_PANEL_VS_HOLD			(KEY_ID_MIN + 354)
#define	KEY_AP_PANEL_SPEED_HOLD			(KEY_ID_MIN + 355)
#define	KEY_AP_ALT_VAR_INC				(KEY_ID_MIN + 356)
#define	KEY_AP_ALT_VAR_DEC				(KEY_ID_MIN + 357)
#define	KEY_AP_VS_VAR_INC				(KEY_ID_MIN + 358)
#define	KEY_AP_VS_VAR_DEC				(KEY_ID_MIN + 359)
#define	KEY_AP_SPD_VAR_INC				(KEY_ID_MIN + 360)
#define	KEY_AP_SPD_VAR_DEC				(KEY_ID_MIN + 361)
#define	KEY_AP_N1_REF_INC				(KEY_ID_MIN + 362)
#define	KEY_AP_N1_REF_DEC				(KEY_ID_MIN + 363)
#define	KEY_MULTIPLAYER_TRACK_TOGGLE	(KEY_ID_MIN + 364)
#define	KEY_MULTIPLAYER_PLAYER_TOGGLE	(KEY_ID_MIN + 365)
#define	KEY_MULTIPLAYER_PLAYER_SNAP		(KEY_ID_MIN + 366)
#define	KEY_MULTIPLAYER_GO_OBSERVER		(KEY_ID_MIN + 367)
#define	KEY_MULTIPLAYER_CHAT			(KEY_ID_MIN + 368)
#define	KEY_MULTIPLAYER_ACTIVATE_CHAT	(KEY_ID_MIN + 369)
#define	KEY_PANEL_1						(KEY_ID_MIN + 370)
#define	KEY_PANEL_2						(KEY_ID_MIN + 371)
#define	KEY_PANEL_3						(KEY_ID_MIN + 372)
#define	KEY_PANEL_4						(KEY_ID_MIN + 373)
#define	KEY_PANEL_5						(KEY_ID_MIN + 374)
#define	KEY_PANEL_6						(KEY_ID_MIN + 375)
#define	KEY_PANEL_7						(KEY_ID_MIN + 376)
#define	KEY_PANEL_8						(KEY_ID_MIN + 377)
#define	KEY_PANEL_9						(KEY_ID_MIN + 378)
#define	KEY_AP_PANEL_MACH_HOLD			(KEY_ID_MIN + 379)
#define	KEY_AP_MACH_VAR_INC				(KEY_ID_MIN + 380)
#define	KEY_AP_MACH_VAR_DEC				(KEY_ID_MIN + 381)
#define	KEY_AP_MACH_HOLD				(KEY_ID_MIN + 382)
//

// These events were added with the converter patch release
#define	KEY_MIXTURE1_SET				(KEY_ID_MIN + 383)
#define	KEY_MIXTURE2_SET				(KEY_ID_MIN + 384)
#define	KEY_MIXTURE3_SET				(KEY_ID_MIN + 385)
#define	KEY_MIXTURE4_SET				(KEY_ID_MIN + 386)
#define	KEY_PROP_PITCH1_SET				(KEY_ID_MIN + 387)
#define	KEY_PROP_PITCH2_SET				(KEY_ID_MIN + 388)
#define	KEY_PROP_PITCH3_SET				(KEY_ID_MIN + 389)
#define	KEY_PROP_PITCH4_SET				(KEY_ID_MIN + 390)
#define	KEY_MAGNETO1_OFF				(KEY_ID_MIN + 391)
#define	KEY_STARTER1_OFF				(KEY_ID_MIN + 391)
#define	KEY_MAGNETO1_RIGHT				(KEY_ID_MIN + 392)
#define	KEY_STARTER1_START				(KEY_ID_MIN + 392)
#define	KEY_MAGNETO1_LEFT				(KEY_ID_MIN + 393)
#define	KEY_STARTER1_GEN				(KEY_ID_MIN + 393)
#define	KEY_MAGNETO1_BOTH				(KEY_ID_MIN + 394)
#define	KEY_MAGNETO1_START				(KEY_ID_MIN + 395)
#define	KEY_MAGNETO1_SET				(KEY_ID_MIN + 396)
#define	KEY_STARTER1_SET				(KEY_ID_MIN + 396)
#define	KEY_MAGNETO2_OFF				(KEY_ID_MIN + 397)
#define	KEY_STARTER2_OFF				(KEY_ID_MIN + 397)
#define	KEY_MAGNETO2_RIGHT				(KEY_ID_MIN + 398)
#define	KEY_STARTER2_START				(KEY_ID_MIN + 398)
#define	KEY_MAGNETO2_LEFT				(KEY_ID_MIN + 399)
#define	KEY_STARTER2_GEN				(KEY_ID_MIN + 399)
#define	KEY_MAGNETO2_BOTH				(KEY_ID_MIN + 400)
#define	KEY_MAGNETO2_START				(KEY_ID_MIN + 401)
#define	KEY_MAGNETO2_SET				(KEY_ID_MIN + 402)
#define	KEY_STARTER2_SET				(KEY_ID_MIN + 402)
#define	KEY_MAGNETO3_OFF				(KEY_ID_MIN + 403)
#define	KEY_STARTER3_OFF				(KEY_ID_MIN + 403)
#define	KEY_MAGNETO3_RIGHT				(KEY_ID_MIN + 404)
#define	KEY_STARTER3_START				(KEY_ID_MIN + 404)
#define	KEY_MAGNETO3_LEFT				(KEY_ID_MIN + 405)
#define	KEY_STARTER3_GEN				(KEY_ID_MIN + 405)
#define	KEY_MAGNETO3_BOTH				(KEY_ID_MIN + 406)
#define	KEY_MAGNETO3_START				(KEY_ID_MIN + 407)
#define	KEY_MAGNETO3_SET				(KEY_ID_MIN + 408)
#define	KEY_STARTER3_SET				(KEY_ID_MIN + 408)
#define	KEY_MAGNETO4_OFF				(KEY_ID_MIN + 409)
#define	KEY_STARTER4_OFF				(KEY_ID_MIN + 409)
#define	KEY_MAGNETO4_RIGHT				(KEY_ID_MIN + 410)
#define	KEY_STARTER4_START				(KEY_ID_MIN + 410)
#define	KEY_MAGNETO4_LEFT				(KEY_ID_MIN + 411)
#define	KEY_STARTER4_GEN				(KEY_ID_MIN + 411)
#define	KEY_MAGNETO4_BOTH				(KEY_ID_MIN + 412)
#define	KEY_MAGNETO4_START				(KEY_ID_MIN + 413)
#define	KEY_MAGNETO4_SET				(KEY_ID_MIN + 414)
#define	KEY_STARTER4_SET				(KEY_ID_MIN + 414)
#define	KEY_AUTOCOORD_TOGGLE			(KEY_ID_MIN + 415)
#define	KEY_AUTOCOORD_OFF				(KEY_ID_MIN + 416)
#define	KEY_AUTOCOORD_ON				(KEY_ID_MIN + 417)
#define	KEY_AUTOCOORD_SET				(KEY_ID_MIN + 418)
#define	KEY_FUEL_SELECTOR_OFF			(KEY_ID_MIN + 419)
#define	KEY_FUEL_SELECTOR_ALL			(KEY_ID_MIN + 420)
#define	KEY_FUEL_SELECTOR_LEFT			(KEY_ID_MIN + 421)
#define	KEY_FUEL_SELECTOR_RIGHT			(KEY_ID_MIN + 422)
#define	KEY_FUEL_SELECTOR_LEFT_AUX		(KEY_ID_MIN + 423)
#define	KEY_FUEL_SELECTOR_RIGHT_AUX		(KEY_ID_MIN + 424)
#define	KEY_FUEL_SELECTOR_CENTER		(KEY_ID_MIN + 425)
#define	KEY_FUEL_SELECTOR_SET			(KEY_ID_MIN + 426)
#define	KEY_THROTTLE1_FULL				(KEY_ID_MIN + 427)
#define	KEY_THROTTLE1_INCR				(KEY_ID_MIN + 428)
#define	KEY_THROTTLE1_INCR_SMALL		(KEY_ID_MIN + 429)
#define	KEY_THROTTLE1_DECR				(KEY_ID_MIN + 430)
#define	KEY_THROTTLE1_CUT				(KEY_ID_MIN + 431)
#define	KEY_THROTTLE2_FULL				(KEY_ID_MIN + 432)
#define	KEY_THROTTLE2_INCR				(KEY_ID_MIN + 433)
#define	KEY_THROTTLE2_INCR_SMALL		(KEY_ID_MIN + 434)
#define	KEY_THROTTLE2_DECR				(KEY_ID_MIN + 435)
#define	KEY_THROTTLE2_CUT				(KEY_ID_MIN + 436)
#define	KEY_THROTTLE3_FULL				(KEY_ID_MIN + 437)
#define	KEY_THROTTLE3_INCR				(KEY_ID_MIN + 438)
#define	KEY_THROTTLE3_INCR_SMALL		(KEY_ID_MIN + 439)
#define	KEY_THROTTLE3_DECR				(KEY_ID_MIN + 440)
#define	KEY_THROTTLE3_CUT				(KEY_ID_MIN + 441)
#define	KEY_THROTTLE4_FULL				(KEY_ID_MIN + 442)
#define	KEY_THROTTLE4_INCR				(KEY_ID_MIN + 443)
#define	KEY_THROTTLE4_INCR_SMALL		(KEY_ID_MIN + 444)
#define	KEY_THROTTLE4_DECR				(KEY_ID_MIN + 445)
#define	KEY_THROTTLE4_CUT				(KEY_ID_MIN + 446)
#define	KEY_MIXTURE1_RICH				(KEY_ID_MIN + 447)
#define	KEY_MIXTURE1_INCR				(KEY_ID_MIN + 448)
#define	KEY_MIXTURE1_INCR_SMALL			(KEY_ID_MIN + 449)
#define	KEY_MIXTURE1_DECR				(KEY_ID_MIN + 450)
#define	KEY_MIXTURE1_LEAN				(KEY_ID_MIN + 451)
#define	KEY_MIXTURE2_RICH				(KEY_ID_MIN + 452)
#define	KEY_MIXTURE2_INCR				(KEY_ID_MIN + 453)
#define	KEY_MIXTURE2_INCR_SMALL			(KEY_ID_MIN + 454)
#define	KEY_MIXTURE2_DECR				(KEY_ID_MIN + 455)
#define	KEY_MIXTURE2_LEAN				(KEY_ID_MIN + 456)
#define	KEY_MIXTURE3_RICH				(KEY_ID_MIN + 457)
#define	KEY_MIXTURE3_INCR				(KEY_ID_MIN + 458)
#define	KEY_MIXTURE3_INCR_SMALL			(KEY_ID_MIN + 459)
#define	KEY_MIXTURE3_DECR				(KEY_ID_MIN + 460)
#define	KEY_MIXTURE3_LEAN				(KEY_ID_MIN + 461)
#define	KEY_MIXTURE4_RICH				(KEY_ID_MIN + 462)
#define	KEY_MIXTURE4_INCR				(KEY_ID_MIN + 463)
#define	KEY_MIXTURE4_INCR_SMALL			(KEY_ID_MIN + 464)
#define	KEY_MIXTURE4_DECR				(KEY_ID_MIN + 465)
#define	KEY_MIXTURE4_LEAN				(KEY_ID_MIN + 466)
#define	KEY_PROP_PITCH1_LO				(KEY_ID_MIN + 467)
#define	KEY_PROP_PITCH1_INCR			(KEY_ID_MIN + 468)
#define	KEY_PROP_PITCH1_INCR_SMALL		(KEY_ID_MIN + 469)
#define	KEY_PROP_PITCH1_DECR			(KEY_ID_MIN + 470)
#define	KEY_PROP_PITCH1_HI				(KEY_ID_MIN + 471)
#define	KEY_PROP_PITCH2_LO				(KEY_ID_MIN + 472)
#define	KEY_PROP_PITCH2_INCR			(KEY_ID_MIN + 473)
#define	KEY_PROP_PITCH2_INCR_SMALL		(KEY_ID_MIN + 474)
#define	KEY_PROP_PITCH2_DECR			(KEY_ID_MIN + 475)
#define	KEY_PROP_PITCH2_HI				(KEY_ID_MIN + 476)
#define	KEY_PROP_PITCH3_LO				(KEY_ID_MIN + 477)
#define	KEY_PROP_PITCH3_INCR			(KEY_ID_MIN + 478)
#define	KEY_PROP_PITCH3_INCR_SMALL		(KEY_ID_MIN + 479)
#define	KEY_PROP_PITCH3_DECR			(KEY_ID_MIN + 480)
#define	KEY_PROP_PITCH3_HI				(KEY_ID_MIN + 481)
#define	KEY_PROP_PITCH4_LO				(KEY_ID_MIN + 482)
#define	KEY_PROP_PITCH4_INCR			(KEY_ID_MIN + 483)
#define	KEY_PROP_PITCH4_INCR_SMALL		(KEY_ID_MIN + 484)
#define	KEY_PROP_PITCH4_DECR			(KEY_ID_MIN + 485)
#define	KEY_PROP_PITCH4_HI				(KEY_ID_MIN + 486)
#define	KEY_MAGNETO_OFF					(KEY_ID_MIN + 487)
#define	KEY_STARTER_OFF					(KEY_ID_MIN + 487)
#define	KEY_MAGNETO_RIGHT				(KEY_ID_MIN + 488)
#define	KEY_STARTER_START				(KEY_ID_MIN + 488)
#define	KEY_MAGNETO_LEFT				(KEY_ID_MIN + 489)
#define	KEY_STARTER_GEN					(KEY_ID_MIN + 489)
#define	KEY_MAGNETO_BOTH				(KEY_ID_MIN + 490)
#define	KEY_MAGNETO_START				(KEY_ID_MIN + 491)
#define	KEY_MAGNETO_SET					(KEY_ID_MIN + 492)
#define	KEY_STARTER_SET					(KEY_ID_MIN + 492)
// end of events added for converter patch release

// These events were added in the Patch Set 1 for FS98
#define	KEY_ANTI_ICE_ON					(KEY_ID_MIN + 493)
#define	KEY_ANTI_ICE_OFF				(KEY_ID_MIN + 494)
#define	KEY_ANTI_ICE_SET				(KEY_ID_MIN + 495)
#define	KEY_EGT_INC						(KEY_ID_MIN + 496)
#define	KEY_EGT_DEC						(KEY_ID_MIN + 497)
#define	KEY_EGT_SET						(KEY_ID_MIN + 498)
#define	KEY_AP_ALT_VAR_SET_METRIC		(KEY_ID_MIN + 499)
#define	KEY_AP_VS_VAR_SET_ENGLISH		(KEY_ID_MIN + 500)
#define	KEY_AP_SPD_VAR_SET				(KEY_ID_MIN + 501)
#define	KEY_AP_MACH_VAR_SET				(KEY_ID_MIN + 502)
#define	KEY_ADF_CARD_SET				(KEY_ID_MIN + 503)
#define	KEY_KOHLSMAN_SET				(KEY_ID_MIN + 504)
#define	KEY_SIM_RATE_SET				(KEY_ID_MIN + 505)
#define	KEY_HEADING_BUG_SET				(KEY_ID_MIN + 506)
#define	KEY_TRUE_AIRSPEED_CAL_SET		(KEY_ID_MIN + 507)
#define	KEY_CLOCK_HOURS_SET				(KEY_ID_MIN + 508)
#define	KEY_CLOCK_MINUTES_SET			(KEY_ID_MIN + 509)
#define	KEY_GYRO_DRIFT_SET				(KEY_ID_MIN + 510)
#define	KEY_ADF_EXTENDED_SET			(KEY_ID_MIN + 511)
#define	KEY_SLEW_SET					(KEY_ID_MIN + 512)
#define	KEY_SMOKE_ON					(KEY_ID_MIN + 513)
#define	KEY_SMOKE_OFF					(KEY_ID_MIN + 514)
#define	KEY_SMOKE_SET					(KEY_ID_MIN + 515)
#define	KEY_STROBES_ON					(KEY_ID_MIN + 516)
#define	KEY_STROBES_OFF					(KEY_ID_MIN + 517)
#define	KEY_STROBES_SET					(KEY_ID_MIN + 518)
#define	KEY_PAUSE_SET					(KEY_ID_MIN + 519)
#define	KEY_PANEL_LIGHTS_ON				(KEY_ID_MIN + 520)
#define	KEY_PANEL_LIGHTS_OFF			(KEY_ID_MIN + 521)
#define	KEY_PANEL_LIGHTS_SET			(KEY_ID_MIN + 522)
#define	KEY_LANDING_LIGHTS_ON			(KEY_ID_MIN + 523)
#define	KEY_LANDING_LIGHTS_OFF			(KEY_ID_MIN + 524)
#define	KEY_LANDING_LIGHTS_SET			(KEY_ID_MIN + 525)
#define	KEY_SOUND_ON					(KEY_ID_MIN + 526)
#define	KEY_SOUND_OFF					(KEY_ID_MIN + 527)
#define	KEY_SPOILERS_ON					(KEY_ID_MIN + 528)
#define	KEY_SPOILERS_OFF				(KEY_ID_MIN + 529)
#define	KEY_SPOILERS_ARM_ON				(KEY_ID_MIN + 530)
#define	KEY_SPOILERS_ARM_OFF			(KEY_ID_MIN + 531)
#define	KEY_SPOILERS_ARM_SET			(KEY_ID_MIN + 532)
#define	KEY_YAW_DAMPER_ON				(KEY_ID_MIN + 533)
#define	KEY_YAW_DAMPER_OFF				(KEY_ID_MIN + 534)
#define	KEY_YAW_DAMPER_SET				(KEY_ID_MIN + 535)
#define	KEY_PITOT_HEAT_ON				(KEY_ID_MIN + 536)
#define	KEY_PITOT_HEAT_OFF				(KEY_ID_MIN + 537)
#define	KEY_PITOT_HEAT_SET				(KEY_ID_MIN + 538)
#define	KEY_ZULU_HOURS_SET				(KEY_ID_MIN + 539)
#define	KEY_ZULU_MINUTES_SET			(KEY_ID_MIN + 540)
#define	KEY_ZULU_DAY_SET				(KEY_ID_MIN + 541)
#define	KEY_ZULU_YEAR_SET				(KEY_ID_MIN + 542)
#define	KEY_GEAR_UP						(KEY_ID_MIN + 543)
#define	KEY_GEAR_DOWN					(KEY_ID_MIN + 544)
#define	KEY_EGT1_INC					(KEY_ID_MIN + 545)
#define	KEY_EGT1_DEC					(KEY_ID_MIN + 546)
#define	KEY_EGT1_SET					(KEY_ID_MIN + 547)
#define	KEY_EGT2_INC					(KEY_ID_MIN + 548)
#define	KEY_EGT2_DEC					(KEY_ID_MIN + 549)
#define	KEY_EGT2_SET					(KEY_ID_MIN + 550)
#define	KEY_EGT3_INC					(KEY_ID_MIN + 551)
#define	KEY_EGT3_DEC					(KEY_ID_MIN + 552)
#define	KEY_EGT3_SET					(KEY_ID_MIN + 553)
#define	KEY_EGT4_INC					(KEY_ID_MIN + 554)
#define	KEY_EGT4_DEC					(KEY_ID_MIN + 555)
#define	KEY_EGT4_SET					(KEY_ID_MIN + 556)
#define	KEY_AP_AIRSPEED_ON				(KEY_ID_MIN + 557)
#define	KEY_AP_AIRSPEED_OFF				(KEY_ID_MIN + 558)
#define	KEY_AP_AIRSPEED_SET				(KEY_ID_MIN + 559)
#define	KEY_AP_MACH_ON					(KEY_ID_MIN + 560)
#define	KEY_AP_MACH_OFF					(KEY_ID_MIN + 561)
#define	KEY_AP_MACH_SET					(KEY_ID_MIN + 562)
#define	KEY_AP_VS_HOLD					(KEY_ID_MIN + 563)
#define	KEY_AP_VS_ON					(KEY_ID_MIN + 564)
#define	KEY_AP_VS_OFF					(KEY_ID_MIN + 565)
#define	KEY_AP_VS_SET					(KEY_ID_MIN + 566)
#define	KEY_AP_PANEL_ALTITUDE_ON		(KEY_ID_MIN + 567)
#define	KEY_AP_PANEL_ALTITUDE_OFF		(KEY_ID_MIN + 568)
#define	KEY_AP_PANEL_ALTITUDE_SET		(KEY_ID_MIN + 569)
#define	KEY_AP_PANEL_HEADING_ON			(KEY_ID_MIN + 570)
#define	KEY_AP_PANEL_HEADING_OFF		(KEY_ID_MIN + 571)
#define	KEY_AP_PANEL_HEADING_SET		(KEY_ID_MIN + 572)
#define	KEY_AP_PANEL_MACH_ON			(KEY_ID_MIN + 573)
#define	KEY_AP_PANEL_MACH_OFF			(KEY_ID_MIN + 574)
#define	KEY_AP_PANEL_MACH_SET			(KEY_ID_MIN + 575)
#define	KEY_AP_PANEL_SPEED_ON			(KEY_ID_MIN + 576)
#define	KEY_AP_PANEL_SPEED_OFF			(KEY_ID_MIN + 577)
#define	KEY_AP_PANEL_SPEED_SET			(KEY_ID_MIN + 578)
#define	KEY_AP_PANEL_VS_ON				(KEY_ID_MIN + 579)
#define	KEY_AP_PANEL_VS_OFF				(KEY_ID_MIN + 580)
#define	KEY_AP_PANEL_VS_SET				(KEY_ID_MIN + 581)
#define	KEY_SEE_OWN_AC_TOGGLE			(KEY_ID_MIN + 582)
#define	KEY_SEE_OWN_AC_ON				(KEY_ID_MIN + 583)
#define	KEY_SEE_OWN_AC_OFF				(KEY_ID_MIN + 584)
#define	KEY_SEE_OWN_AC_SET				(KEY_ID_MIN + 585)
#define	KEY_ADF_LOWRANGE_SET			(KEY_ID_MIN + 586)
#define	KEY_ADF_HIGHRANGE_SET			(KEY_ID_MIN + 587)
#define	KEY_AP_ALT_VAR_SET_ENGLISH		(KEY_ID_MIN + 588)
#define	KEY_AP_VS_VAR_SET_METRIC		(KEY_ID_MIN + 589)
#define	KEY_MAGNETO1_DECR				(KEY_ID_MIN + 590)
#define	KEY_MAGNETO1_INCR				(KEY_ID_MIN + 591)
#define	KEY_MAGNETO2_DECR				(KEY_ID_MIN + 592)
#define	KEY_MAGNETO2_INCR				(KEY_ID_MIN + 593)
#define	KEY_MAGNETO3_DECR				(KEY_ID_MIN + 594)
#define	KEY_MAGNETO3_INCR				(KEY_ID_MIN + 595)
#define	KEY_MAGNETO4_DECR				(KEY_ID_MIN + 596)
#define	KEY_MAGNETO4_INCR				(KEY_ID_MIN + 597)
// end of events added with Patch Set 1 for FS98


//
// Common Flight Simulator Data Types
//

typedef	VOID			*PVOID;
typedef	PVOID			*PPVOID;

typedef	unsigned	char	UINT8, *PUINT8, **PPUINT8;
typedef	signed		char	SINT8, *PSINT8, **PPSINT8;
typedef	unsigned	short	UINT16, *PUINT16, **PPUINT16;
typedef	signed		short	SINT16, *PSINT16, **PPSINT16;
typedef	unsigned	long	UINT32, *PUINT32, **PPUINT32;
typedef	signed		long	SINT32, *PSINT32, **PPSINT32;

typedef	unsigned	char	VAR8, *PVAR8, **PPVAR8;
typedef	unsigned	short	VAR16, *PVAR16, **PPVAR16;
typedef	unsigned	long	VAR32, *PVAR32, **PPVAR32;

// SINT48 is defined later, after ANGL48

// 64-bit generic structure
typedef struct	VAR64
{
	VAR32	lo;
	VAR32	hi;
} VAR64, *PVAR64, **PPVAR64;

// 64-bit int mainly for square root
typedef	struct	UINT64
{
	UINT32	lo;
	UINT32	hi;
} UINT64, *PUINT64, **PPUINT64;

typedef struct	SINT64
{
	UINT32	lo;
	SINT32	hi;
} SINT64, *PSINT64, **PPSINT64;

// boolean variables - hold TRUE/FALSE
typedef	int		BOOL, *PBOOL, **PPBOOL;
typedef	VAR8	BOOL8, *PBOOL8, **PPBOOL8;
typedef	VAR16	BOOL16, *PBOOL16, **PPBOOL16;
typedef	VAR32	BOOL32, *PBOOL32, **PPBOOL32;

// array of 1-bit boolean variables
typedef int		FLAGS, *PFLAGS, **PPFLAGS;
typedef VAR8	FLAGS8, *PFLAGS8, **PPFLAGS8;
typedef VAR16	FLAGS16, *PFLAGS16, **PPFLAGS16;
typedef VAR32	FLAGS32, *PFLAGS32, **PPFLAGS32;

// Enumeration variables - domain is subset of all possible values
typedef int		ENUM, *PENUM, **PPENUM;
typedef VAR8	ENUM8, *PENUM8, **PPENUM8;
typedef VAR16	ENUM16, *PENUM16, **PPENUM16;
typedef VAR32	ENUM32, *PENUM32, **PPENUM32;

// Identifier variables
typedef int		ID, *PID, **PPID;
typedef VAR8	ID8, *PID8, **PPID8;
typedef VAR16	ID16, *PID16, **PPID16;
typedef VAR32	ID32, *PID32, **PPID32;

// Error return variables
typedef	VAR32	ERR, *PERR, **PPERR;

// Fractional variables
typedef UINT8	UFRAC8, *PUFRAC8, **PPUFRAC8;	 // { 0..+1}
typedef SINT8	SFRAC8, *PSFRAC8, **PPSFRAC8;	 // {-1..+1}
typedef UINT16	UFRAC16, *PUFRAC16, **PPUFRAC16; // { 0..+1}
typedef SINT16	SFRAC16, *PSFRAC16, **PPSFRAC16; // {-1..+1}
typedef UINT32	UFRAC32, *PUFRAC32, **PPUFRAC32; // { 0..+1}
typedef SINT32	SFRAC32, *PSFRAC32, **PPSFRAC32; // {-1..+1}

// Integer/Fraction structures
typedef	UINT16	UIF16, *PUIF16, **PPUIF16;
typedef	SINT16	SIF16, *PSIF16, **PPSIF16;
typedef struct	UIF48
{
	UINT16	pad;
	UINT16	f;
	UINT32	i;
} UIF48, *PUIF48, **PPUIF48;

typedef	UINT32	UIF32, *PUIF32, **PPUIF32;
typedef	SINT32	SIF32, *PSIF32, **PPSIF32;
typedef struct	SIF48
{
	UINT16	pad;
	UINT16	f;
	SINT32	i;
} SIF48, *PSIF48, **PPSIF48;

typedef SINT64	SIF64, *PSIF64, **PPSIF64;

// Floating-point types
typedef double	FLOAT64, *PFLOAT64, **PPFLOAT64;

#if !defined(_WINNT_)				// NOT PORTABLE!
typedef	VAR8	CHAR;
typedef VAR8	*PCHAR;			 	// single character
#endif
typedef	PCHAR	*PPCHAR;			// pointer to pointer to char
typedef CHAR	STRING, *PSTRING, **PPSTRING;		// generic string of unknown length
typedef CHAR	STRINGZ, *PSTRINGZ, **PPSTRINGZ;	// generic string of unknown length, zero term

typedef VAR16	BCD16, *PBCD16, **PPBCD16;		// 4-digit BCD number (0000-9999)
typedef VAR16	BCO16, *PBCO16, **PPBCO16;		// 4-digit Octal number (0000-7777) (in BCD)
typedef	VAR32	BCD32, *PBCD32, **PPBCD32;		// 8-digit BCD number (00000000-99999999)

// pseudodegree variables
typedef VAR8	ANGL8, *PANGL8, **PPANGL8;
typedef VAR16	ANGL16, *PANGL16, **PPANGL16;
typedef VAR32	ANGL32, *PANGL32, **PPANGL32;
typedef struct	ANGL48
{
	UINT16	pad;
	UINT16	lo;
	UINT32	hi;
} ANGL48, *PANGL48, **PPANGL48;

typedef	ANGL48	SINT48, *PSINT48, **PPSINT48;


//	2D data structures
typedef SINT32	PIXEL, *PPIXEL, **PPPIXEL;		// screen pixel

typedef struct	PIXPOINT
{
	PIXEL x;
	PIXEL y;
} PIXPOINT, *PPIXPOINT, **PPPIXPOINT;

typedef struct	PIXBOX
{
	PIXEL x;
	PIXEL y;
	PIXEL size_x;
	PIXEL size_y;
} PIXBOX, *PPIXBOX, **PPPIXBOX;


// enum constants for IMAGE.format
typedef	enum IMG_FORMAT
{
	IMG_8_BIT_MONOCHROME = 0,
	IMG_8_BIT_INDEXED,
	IMG_15_BIT,
	IMG_16_BIT,
	IMG_24_BIT,
	IMG_32_BIT,
	IMG_MAX							// keep this last
} IMG_FORMAT;

// IMAGE - structure containing info pertaining to an offscreen image buffer
typedef	struct	IMAGE
{
	IMG_FORMAT	format;		// bit format for this image
	PIXPOINT	dim;		// offscreen buffer size (viewable area)
	UINT32		pitch;		// offset to add to advance one scan line in image buffer
	PPCHAR		rowtbl;		// array of dim.y entries containing absolute address of scan lines in image buffer
	UINT32		len;		// allocated length of image buffer
	PCHAR		image;		// pointer to image buffer
	PVOID		surface;	// direct draw surface.
} IMAGE, *PIMAGE, **PPIMAGE;


// Engine structure
typedef	struct	ENG
{
// ITEMS SAVED TO SITUATION FILE *****************************************
	SINT16		throttle_lvr_pos;		// throttle position (0-16384=>0-100%throttle position)
	UINT16		propeller_lvr_pos;		// propeller lever position (0-16384=>0-100%prop setting)
	UINT16		mixture_lvr_pos;		// mixture position (0-16384=>0-100%mixture position)
	ENUM16		starter;				// starter switch position

	BOOL16		combustion;				// combustion flag (combustion = TRUE)
	UINT16		n1_rpm;					// gas producer RPM (0-16384=>0-100%RPM)
	UINT16		n2_rpm;					// power RPM (0-16384=>0-100%RPM)
	UINT16		ff_pph;					// fuel flow (0-16384=>0-100%)PPH (normalized to Lear 3500 lbs thrust)
	UINT32		ff_pph_actual;          // fuel flow (0-16384=>0-100%)PPH
	UINT16		ff_pph_ssl;				// fuel flow (0-16384=>0-100%)PPH, Standard sea level conditions
	UINT16		torque;					// torque produced by engine (FT*LBS)
	UINT16		absorbed_torque;		// torque absorbed by propeller (FT*LBS)
	SINT32		thrust_lbs;				// thrust (LBS)
	ANGL16		blade_angle_pdeg;		// propeller blade angle (PDEG)

	BOOL16		lf_mag;					// left magneto status (activated = 1)
	BOOL16		rt_mag;					// right magneto status (activated = 1)
	BOOL16		anti_ice;				// anti ice switch
	UINT16		epr_bug_pos;			// epr governed engine setting (0-16384=>0-100%epr setting)
	UINT16		egt_bug_pos;			// egt governed engine setting (0-16384=>0-100%egt setting)

	UINT16		oil_tmp;				// oil temperature (degC) * 16384
	UINT16		oil_prs;				// oil pressure (PSI) * 16384
	UINT16		epr;					// engine pressure ratio (0-65536=>0-6.4)
	UINT16		egt_degC;				// exhaust gas temperature (degC)
	UINT16		manifold_pressure;		// manifold pressure (0-65536=>0-64)

// ITEMS NOT SAVED TO SITUATION FILE *****************************************
	SINT16		x_pos;					// lateral engine position (IN)
	SINT16		y_pos;					// vertical engine position (IN)
	SINT16		z_pos;					// longitudinal engine position (IN)

	UINT16		rpm_scaler;				// *16384 gives actual prop rpm in dx (= 65535 for jets)
	PVOID		ext_ptr;				// engine structure extension pointer

	UINT32		oil_quantity;			//oil quantity (0-16384 => 0-100%)
	UINT32		engine_vibration;		//oil quantity (0-16384 => 0-5)
	UINT32		hydraulic_pressure;     //hydraulic pressure (0-16384 => 0-4 psi)
	UINT32		hydraulic_quantity;		//hydraulic quantity (0-16384 => 0-100%)
	FLOAT64		induced_velocity;		//induced velocity from propwash or jet blast

	FLOAT64		cyl_head_temp_degF;		//cylinder head temperature (deg F)

// new variables due to addition of the helicopter

	UINT32		tot_ind;	  			// TOT * 16384, deg C
	UINT32		torque_ind;				// TQ * 16384, %
	UINT32		Wfpress_ind;			// Fuel Pressure * 16384, psi
	UINT32		electric_load;			// electrical load * 16384, % max load
	UINT32		xmsn_pressure;			// xmsn pressure * 16384, psi
	UINT32		xmsn_temperature;		// transmission temp * 16384, deg C
	UINT32		rotor_rpm;				// main rotor speed * 16384, % max


//	NEW FUEL VARIABLES
	ENUM  		tank_selector;			//what tanks are selected to draw from
	FLAGS 		tanks_used;				//what tanks are actually being drawn from
	UINT32 		number_of_tanks_used;	//# of tanks being drawn from
	FLOAT64 	fuelflow_pph;			//lbs/hr
	BOOL32 		fuel_available;			//True or False in selected tanks

// end of new variables

} ENG, *PENG, **PPENG;


// fuel_tank_selector enum values
typedef	enum	FUEL_SELECT
{
	FUEL_TANK_SELECTOR_OFF = 0,
	FUEL_TANK_SELECTOR_ALL,
	FUEL_TANK_SELECTOR_LEFT,
	FUEL_TANK_SELECTOR_RIGHT,
	FUEL_TANK_SELECTOR_LEFT_AUX,
	FUEL_TANK_SELECTOR_RIGHT_AUX,
	FUEL_TANK_SELECTOR_CENTER,
	FUEL_TANK_SELECTOR_CROSSFEED,

	FUEL_TANK_MAXIMUM
} FUEL_SELECT, *PFUEL_SELECT, **PPFUEL_SELECT;

// cross feed enum values
typedef	enum	CROSS_FEED_SELECT
{
	CROSS_FEED_OFF = 0,
	CROSS_FEED_LEFT_TO_RIGHT,
	CROSS_FEED_RIGHT_TO_LEFT,

	CROSS_FEED_MAX
} CROSS_FEED, *PCROSS_FEED, **PPCROSS_FEED;

// prop type enum values
typedef enum PROP_TYPE
{
	PROP_TYPE_NONE,
	PROP_TYPE_FIXED,
	PROP_TYPE_MANUAL,
	PROP_TYPE_CHOICE
} PROP_TYPE;

// units enum values
typedef enum UNITS_OF_MEASURE
{
	ENGLISH_UNITS,
	METRIC_UNITS_ALT_FEET,
	METRIC_UNITS_ALT_METER
} UNITS_OF_MEASURE;

//
//	Panel System types and defines
//

//	Token list
//
//	Token list for abstracted variable access
//	The order of variables in this list is tied to the token map in the
//	file panels\util_defs.c.  Every token here needs an entry in the
//	token map, which maps tokens to variables in memory.
//
//	There are two types of tokens.  Normal tokens are used for all the
//	variables in GLOBALS, as well as variables exported from modules.
//	Special tokens are used for variables which require a function call
//	to get the required information.
//
//	Tokens can be added anywhere in the list, but keep the lists aligned!
//
//	DO NOT CHANGE THE ORDER OF THESE TOKENS UNLESS YOU REALLY KNOW WHAT
//	YOU'RE DOING!
//

typedef	enum	GAUGE_TOKEN
{
	MODULE_VAR_NONE = 0,
	TICK18,						//  inc'd at 18hz. used for general purpose timing
	GROUND_ALTITUDE,			//  ground level altitude (1/256 meter/unit)
	CLOCK_HOUR,					//  local clock time, hours {0..23}
	CLOCK_MINUTE,				//  local clock time, minutes {0..59}
	CLOCK_SECOND,				//  local clock time, seconds {0..59}
	ZULU_HOUR,					//  delta time from GMT
	ZULU_MINUTE,				//  delta time from GMT
	ZULU_DAY,					//  GMT day of year (1 - 365/366)
	ZULU_YEAR,					//  GMT year
	PANEL_LIGHTS,				//  TRUE=panel lighting on
	STROBE_LIGHTS,				//  TRUE=strobe lights on
	STROBE_FLASH,				//  TRUE=strobe flash on model & screen
	PITOT_HEAT,					//	TRUE=pitot heat on
	LANDING_LIGHTS,				//  TRUE=landing lights on
	SMOKE_ENABLE,				//  TRUE=smoke system active
	ADF_FREQUENCY,				//  |
	ADF_500_HZ_TUNABLE,			//	|	ADF frequency
	ADF_EXTENDED_FREQUENCY,		//	|
	ADF_IDENTITY,
	ADF_SIGNAL_STRENGTH,
	ADF_MORSE_IDENT,
	ADF_CARD_RADIAL,			//	integer degrees 0-360
	COM_FREQUENCY,				//  BCD COM radio freq
	NAV1_FREQUENCY,				//  BCD NAV1 radio freq
	NAV1_VOR_RADIAL,
	NAV1_MORSE_IDENT,
	NAV2_FREQUENCY,				//  BCD NAV2 radio freq
	NAV2_VOR_RADIAL,
	NAV2_MORSE_IDENT,
	DME1_DISPLAY_TYPE,			//  FALSE=distance readout,  TRUE=speed in kts readout
	DME1_DISTANCE,				//  DME1 distance readout
	DME1_SPEED,					//  DME1 speed readout
	DME1_MORSE_IDENT,
	DME2_DISPLAY_TYPE,			//  FALSE=distance readout,  TRUE=speed in kts readout
	DME2_DISTANCE,				//  DME2 distance readout
	DME2_SPEED,					//  DME2 speed readout
	DME2_MORSE_IDENT,
	TRANSPONDER_CODE,			//  Octal Transponder code {0000 - 7777}
	ADF_NEEDLE,					//	16 bit pseudodegrees
	VOR1_NEEDLE,
	VOR1_GS_NEEDLE,
	VOR1_BACK_COURSE_FLAGS,		//  Status of VOR1 (see BC_FLAG_ in FS6DEF.H)
	VOR1_TF_FLAG,
	VOR1_GS_FLAG,
	VOR1_OBI,
	VOR1_CODE,
	VOR1_IDENTITY,
	VOR1_MAG_VAR,
	VOR1_SIGNAL_STRENGTH,
	VOR2_NEEDLE,
	VOR2_BACK_COURSE_FLAGS,		//  Status of VOR2 (see BC_FLAG_ in FS6DEF.H)
	VOR2_TF_FLAG,
	VOR2_GS_FLAG,
	VOR2_OBI,
	VOR2_CODE,
	VOR2_IDENTITY,
	VOR2_MAG_VAR,
	VOR2_SIGNAL_STRENGTH,
	VOR2_BEARING_DEGREES,
	AIRCRAFT_ON_GROUND,			//  TRUE=aircraft is on the ground
	AIRSPEED,					//	Airspeed - Indicated or True based on GLOBALP->indicated_aspd
	AIRSPEED_TRUE_CALIBRATE,	//	Degrees rotation of the tas calibration card
	BARBER_POLE_ASPD,			//  Movable Red-line airspeed  {1/128th knot/unit}
	MACH,						//  mach, 64k=3.2 mach (would be better as UIF32)
	VERTICAL_SPEED,				//  Velocity Up, vertical speed {1/256th m/sec}
	MACH_MAX_OPERATE,
	STALL_WARNING,				//  TRUE=5 knots before stall
	OVERSPEED_WARNING,			//  TRUE=overspeed warning
	TURN_COORDINATOR_BALL_POS,	//  turn coordinator ball position {-127..0..127}
	DELTA_HEADING_RATE,
	PLANE_LATITUDE,				//  current position of our aircraft
	PLANE_LONGITUDE,			//  current position of our aircraft
	PLANE_ALTITUDE,				//  current position of our aircraft
	ALT_FROM_BAROMETRIC_PRESSURE,
	KOHLSMAN_SETTING_MB,		//  knob position millibars
	KOHLSMAN_SETTING_HG,		//  knob position inches of hg
	PLANE_PITCH_DEGREES,
	ATTITUDE_INDICATOR_PITCH_DEGREES,
	PLANE_BANK_DEGREES,
	ATTITUDE_INDICATOR_BANK_DEGREES,
	PLANE_HEADING_DEGREES_MAGNETIC,
	MAGNETIC_VAR,				//  magnetic north vs. true north angular error
	WHISKEY_COMPASS_DEGREES,	//	True degrees
	PLANE_HEADING_DEGREES_GYRO,
	GYRO_DRIFT_ERROR,
	PLANE_HEADING_DEGREES_TRUE,
	AIRCRAFT_AUTOPILOT_AVAILABLE,
	AIRCRAFT_FLAPS_AVAILABLE,
	AIRCRAFT_STALL_HORN_AVAILABLE,
	AIRCRAFT_ENGINE_MIXTURE_AVAILABLE,
	AIRCRAFT_CARB_HEAT_AVAILABLE,
	AIRCRAFT_SPOILER_AVAILABLE,
	AIRCRAFT_IS_TAIL_DRAGGER,
	AIRCRAFT_STROBES_AVAILABLE,
	AIRCRAFT_PROP_TYPE_AVAILABLE,	//  PROP_TYPE_FIXED, PROP_TYPE_MANUAL, PROP_TYPE_AUTOMATIC
	AIRCRAFT_TOE_BRAKES_AVAILABLE,
	AIRCRAFT_NAV1_AVAILABLE,
	AIRCRAFT_NAV2_AVAILABLE,
	AIRCRAFT_NAV1_OBS_AVAILABLE,
	AIRCRAFT_NAV2_OBS_AVAILABLE,
	AIRCRAFT_VOR2_GAUGE_AVAILABLE,
	AIRCRAFT_GYRO_DRIFT_AVAILABLE,	// fek: may not be used for bug #2131 but making other changes...build build build
	AUTOPILOT_ACTIVE,			//  autopilot master on/off
	AUTOPILOT_WING_LEVELER,		//  wing leveler on/off
	AUTOPILOT_NAV1_LOCK,		//  nav 1 lock on/off
	AUTOPILOT_HEADING_LOCK,		//  heading lock on/off
	AUTOPILOT_HEADING_LOCK_DIR,	//  heading lock direction
	AUTOPILOT_ALTITUDE_LOCK,	//  altitude lock on/off
	AUTOPILOT_ALTITUDE_LOCK_VAR,//  altitude lock altitude in appropriate units
	AUTOPILOT_ATTITUDE_HOLD,	//  attitude hold
	AUTOPILOT_GLIDESLOPE_HOLD,	//  glideslope hold
	AUTOPILOT_APROACH_HOLD,		//  approach hold
	AUTOPILOT_BACKCOURSE_HOLD,	//  backcourse hold
	AUTOPILOT_YAW_DAMPER,		//  yaw damper
	AUTOPILOT_AIRSPEED_HOLD,	//  airspeed hold
	AUTOPILOT_AIRSPEED_HOLD_VAR,//  airspeed hold var
	AUTOPILOT_MACH_HOLD,		//  airspeed hold
	AUTOPILOT_MACH_HOLD_VAR,	//  airspeed hold var
	AUTOPILOT_VERTICAL_HOLD, 	//  vertical hold
	AUTOPILOT_VERTICAL_HOLD_VAR,//  vertical speed hold var in appropriate units
	AUTOPILOT_ALTITUDE_MANUALLY_TUNABLE,
	AUTOPILOT_HEADING_MANUALLY_TUNABLE,
	AUTOPILOT_AUTO_THROTTLE_ARM,
	AUTOPILOT_TAKEOFF_POWER_ACTIVE,
	ENGINE_RPM_HOLD,
	ENGINE_CONTROL_SELECT,		//  which engine is being controlled
	ENGINE1,
	ENGINE1_THROTTLE_LEVER_POS,	//	throttle position			(16k = 100% throttle position)
	ENGINE1_PROPELLER_LEVER_POS,//	propeller lever position	(16k = 100% prop setting)
	ENGINE1_MIXTURE_LEVER_POS,	//	mixture position			(16k = 100% mixture position)
	ENGINE1_COMBUSTION,			//	combustion flag				(combustion = TRUE)
	ENGINE1_STARTER_SWITCH_POS,	//	starter switch position
	ENGINE1_MAGNETO_LEFT,		//	left magneto status			(activated = 1)
	ENGINE1_MAGNETO_RIGHT,		//	right magneto status		(activated = 1)
	ENGINE1_N1_RPM,				//	gas producer (RPM)			(16k = 100% RPM)
	ENGINE1_N2_RPM,				//	power (RPM)					(16k = 100% RPM)
	ENGINE1_FF_GPH,
	ENGINE1_FF_PPH,				//	fuel flow PPH
	ENGINE1_FF_PPH_SSL,			//	fuel flow (PPH)				(16k = 100%, Standard sea level conditions)
	ENGINE1_TORQUE,				//	torque produced ( FT*LBS )
	ENGINE1_ANTI_ICE_SWITCH,	//	anti ice switch
	ENGINE1_PRESSURE_RATIO,		//	engine pressure ratio		(65k = 6.4)
	ENGINE1_PRESSURE_BUG_POS,	//	epr governed engine setting (16k = 100% epr setting)
	ENGINE1_EGT,				//	exhaust gas temp (degC)		(16k = 860 deg)
	ENGINE1_EGT_BUG_POS,		//	egt governed engine setting (16k = 100% egt setting)
	ENGINE1_CHT,				//	cylinder head temperature
	ENGINE1_OIL_TEMPERATURE,	//	oil temperature (degC)		(16k = 140 deg)
	ENGINE1_OIL_PRESSURE,		//	oil pressure (PSI)			(16k = 55 PSI)
	ENGINE1_OIL_QUANTITY,		//	oil quantity				(16k = 100%)
	ENGINE1_HYDRAULIC_PRESSURE,	//	hydraulic pressure (PSI)	(16k = 4 psi)
	ENGINE1_HYDRAULIC_QUANTITY,	//	hydraulic quantity			(16k = 100%)
	ENGINE1_MANIFOLD_PRESSURE,	//	manifold pressure			(65k = 64)
	ENGINE1_ENGINE_VIBRATION,	//	oil quantity				(16k = 5)
	ENGINE1_RPM_SCALER,			//	*16384 gives actual prop rpm in dx (= 65535 for jets)
	ENGINE1_TURBINE_TEMPERATURE,		//	(DegC * 16384)
	ENGINE1_TORQUE_PERCENT,				//	(FT/LBS * 16384)
	ENGINE1_FUEL_PRESSURE,				//	(PSI * 16384)
	ENGINE1_ELECTRICAL_LOAD,			//	(Max Load * 16384)
	ENGINE1_TRANSMISSION_PRESSURE,		//	(PSI * 16384)
	ENGINE1_TRANSMISSION_TEMPERATURE,	//	(DegC * 16384)
	ENGINE1_ROTOR_RPM,					//	(Max 8 16384)
	ENGINE2,
	ENGINE2_THROTTLE_LEVER_POS,	//	throttle position (0-16384=>0-100%throttle position)
	ENGINE2_PROPELLER_LEVER_POS,//	propeller lever position (0-16384=>0-100%prop setting)
	ENGINE2_MIXTURE_LEVER_POS,	//	mixture position (0-16384=>0-100%mixture position)
	ENGINE2_COMBUSTION,			//	combustion flag (combustion = TRUE)
	ENGINE2_STARTER_SWITCH_POS,	//	starter switch position
	ENGINE2_MAGNETO_LEFT,		//	left magneto status (activated = 1)
	ENGINE2_MAGNETO_RIGHT,		//	right magneto status (activated = 1)
	ENGINE2_N1_RPM,				//	gas producer RPM (0-16384=>0-100%RPM)
	ENGINE2_N2_RPM,				//	power RPM (0-16384=>0-100%RPM)
	ENGINE2_FF_GPH,
	ENGINE2_FF_PPH,				//	PPH
	ENGINE2_FF_PPH_SSL,			//	fuel flow (0-16384=>0-100%)PPH, Standard sea level conditions
	ENGINE2_TORQUE,				//	torque produced ( FT*LBS )
	ENGINE2_ANTI_ICE_SWITCH,	//	anti ice switch
	ENGINE2_PRESSURE_RATIO,		//	engine pressure ratio (0-65536=>0-6.4)
	ENGINE2_PRESSURE_BUG_POS,	//	epr governed engine setting (0-16384=>0-100%epr setting)
	ENGINE2_EGT,				//	exhaust gas temperature (degC)
	ENGINE2_EGT_BUG_POS,		//	egt governed engine setting (0-16384=>0-100%egt setting)
	ENGINE2_CHT,				//	cylinder head temperature
	ENGINE2_OIL_TEMPERATURE,	//	oil temperature (degC)
	ENGINE2_OIL_PRESSURE,		//	oil pressure (PSI)
	ENGINE2_OIL_QUANTITY,		//	oil quantity (0-16384 => 0-100%)
	ENGINE2_HYDRAULIC_PRESSURE,	//	hydraulic pressure (0-16384 => 0-4 psi)
	ENGINE2_HYDRAULIC_QUANTITY,	//	hydraulic quantity (0-16384 => 0-100%)
	ENGINE2_MANIFOLD_PRESSURE,	//	manifold pressure (0-65536=>0-64)
	ENGINE2_ENGINE_VIBRATION,	//	oil quantity (0-16384 => 0-5)
	ENGINE2_RPM_SCALER,			//	*16384 gives actual prop rpm in dx (= 65535 for jets)
	ENGINE2_TURBINE_TEMPERATURE,		//	(DegC * 16384)
	ENGINE2_TORQUE_PERCENT,				//	(FT/LBS * 16384)
	ENGINE2_FUEL_PRESSURE,				//	(PSI * 16384)
	ENGINE2_ELECTRICAL_LOAD,			//	(Max Load * 16384)
	ENGINE2_TRANSMISSION_PRESSURE,		//	(PSI * 16384)
	ENGINE2_TRANSMISSION_TEMPERATURE,	//	(DegC * 16384)
	ENGINE2_ROTOR_RPM,					//	(Max 8 16384)
	ENGINE3,
	ENGINE3_THROTTLE_LEVER_POS,	//	throttle position (0-16384=>0-100%throttle position)
	ENGINE3_PROPELLER_LEVER_POS,//	propeller lever position (0-16384=>0-100%prop setting)
	ENGINE3_MIXTURE_LEVER_POS,	//	mixture position (0-16384=>0-100%mixture position)
	ENGINE3_COMBUSTION,			//	combustion flag (combustion = TRUE)
	ENGINE3_STARTER_SWITCH_POS,	//	starter switch position
	ENGINE3_MAGNETO_LEFT,		//	left magneto status (activated = 1)
	ENGINE3_MAGNETO_RIGHT,		//	right magneto status (activated = 1)
	ENGINE3_N1_RPM,				//	gas producer RPM (0-16384=>0-100%RPM)
	ENGINE3_N2_RPM,				//	power RPM (0-16384=>0-100%RPM)
	ENGINE3_FF_GPH,
	ENGINE3_FF_PPH,				//	fuel flow PPH
	ENGINE3_FF_PPH_SSL,			//	fuel flow (0-16384=>0-100%)PPH, Standard sea level conditions
	ENGINE3_TORQUE,				//	torque produced ( FT*LBS )
	ENGINE3_ANTI_ICE_SWITCH,	//	anti ice switch
	ENGINE3_PRESSURE_RATIO,		//	engine pressure ratio (0-65536=>0-6.4)
	ENGINE3_PRESSURE_BUG_POS,	//	epr governed engine setting (0-16384=>0-100%epr setting)
	ENGINE3_EGT,				//	exhaust gas temperature (degC)
	ENGINE3_EGT_BUG_POS,		//	egt governed engine setting (0-16384=>0-100%egt setting)
	ENGINE3_CHT,				//	cylinder head temperature
	ENGINE3_OIL_TEMPERATURE,	//	oil temperature (degC)
	ENGINE3_OIL_PRESSURE,		//	oil pressure (PSI)
	ENGINE3_OIL_QUANTITY,		//	oil quantity (0-16384 => 0-100%)
	ENGINE3_HYDRAULIC_PRESSURE,	//	hydraulic pressure (0-16384 => 0-4 psi)
	ENGINE3_HYDRAULIC_QUANTITY,	//	hydraulic quantity (0-16384 => 0-100%)
	ENGINE3_MANIFOLD_PRESSURE,	//	manifold pressure (0-65536=>0-64)
	ENGINE3_ENGINE_VIBRATION,	//	oil quantity (0-16384 => 0-5)
	ENGINE3_RPM_SCALER,			//	*16384 gives actual prop rpm in dx (= 65535 for jets)
	ENGINE3_TURBINE_TEMPERATURE,		//	(DegC * 16384)
	ENGINE3_TORQUE_PERCENT,				//	(FT/LBS * 16384)
	ENGINE3_FUEL_PRESSURE,				//	(PSI * 16384)
	ENGINE3_ELECTRICAL_LOAD,			//	(Max Load * 16384)
	ENGINE3_TRANSMISSION_PRESSURE,		//	(PSI * 16384)
	ENGINE3_TRANSMISSION_TEMPERATURE,	//	(DegC * 16384)
	ENGINE3_ROTOR_RPM,					//	(Max 8 16384)
	ENGINE4,
	ENGINE4_THROTTLE_LEVER_POS,	//	throttle position (0-16384=>0-100%throttle position)
	ENGINE4_PROPELLER_LEVER_POS,//	propeller lever position (0-16384=>0-100%prop setting)
	ENGINE4_MIXTURE_LEVER_POS,	//	mixture position (0-16384=>0-100%mixture position)
	ENGINE4_COMBUSTION,			//	combustion flag (combustion = TRUE)
	ENGINE4_STARTER_SWITCH_POS,	//	starter switch position
	ENGINE4_MAGNETO_LEFT,		//	left magneto status (activated = 1)
	ENGINE4_MAGNETO_RIGHT,		//	right magneto status (activated = 1)
	ENGINE4_N1_RPM,				//	gas producer RPM (0-16384=>0-100%RPM)
	ENGINE4_N2_RPM,				//	power RPM (0-16384=>0-100%RPM)
	ENGINE4_FF_GPH,
	ENGINE4_FF_PPH,				//	fuel flow PPH
	ENGINE4_FF_PPH_SSL,			//	fuel flow (0-16384=>0-100%)PPH, Standard sea level conditions
	ENGINE4_TORQUE,				//	torque produced ( FT*LBS )
	ENGINE4_ANTI_ICE_SWITCH,	//	anti ice switch
	ENGINE4_PRESSURE_RATIO,		//	engine pressure ratio (0-65536=>0-6.4)
	ENGINE4_PRESSURE_BUG_POS,	//	epr governed engine setting (0-16384=>0-100%epr setting)
	ENGINE4_EGT,				//	exhaust gas temperature (degC)
	ENGINE4_EGT_BUG_POS,		//	egt governed engine setting (0-16384=>0-100%egt setting)
	ENGINE4_CHT,				//	cylinder head temperature
	ENGINE4_OIL_TEMPERATURE,	//	oil temperature (degC)
	ENGINE4_OIL_PRESSURE,		//	oil pressure (PSI)
	ENGINE4_OIL_QUANTITY,		//	oil quantity (0-16384 => 0-100%)
	ENGINE4_HYDRAULIC_PRESSURE,	//	hydraulic pressure (0-16384 => 0-4 psi)
	ENGINE4_HYDRAULIC_QUANTITY,	//	hydraulic quantity (0-16384 => 0-100%)
	ENGINE4_MANIFOLD_PRESSURE,	//	manifold pressure (0-65536=>0-64)
	ENGINE4_ENGINE_VIBRATION,	//	oil quantity (0-16384 => 0-5)
	ENGINE4_RPM_SCALER,			//	*16384 gives actual prop rpm in dx (= 65535 for jets)
	ENGINE4_TURBINE_TEMPERATURE,		//	(DegC * 16384)
	ENGINE4_TORQUE_PERCENT,				//	(FT/LBS * 16384)
	ENGINE4_FUEL_PRESSURE,				//	(PSI * 16384)
	ENGINE4_ELECTRICAL_LOAD,			//	(Max Load * 16384)
	ENGINE4_TRANSMISSION_PRESSURE,		//	(PSI * 16384)
	ENGINE4_TRANSMISSION_TEMPERATURE,	//	(DegC * 16384)
	ENGINE4_ROTOR_RPM,					//	(Max 8 16384)
	NUMBER_OF_ENGINES,			//  1=single 2=twin ...
	PROP_ADVANCE_SELECTION,		//  0=fixed 1=optimal 2=manual
	THROTTLE_LOWER_LIMIT,		//  set by sim for thrust reversers
	OIL_QUANTITY_TOTAL,			//  0..7fff (8 qt.)
	SYSTEMS_AVAILABLE,
	INSTRUMENTS_AVAILABLE,
	PP_ADF,						//  partial panel variables
	PP_AIR,
	PP_ALTIM,
	PP_ATTITUDE,
	PP_COM,
	PP_COMPASS,
	PP_ELECT,
	PP_ENGINE,
	PP_FUEL_IND,
	PP_HEADING,
	PP_VERT_VEL,
	PP_XPNDR,
	PP_NAV,
	PP_PITOT,
	PP_TURN_COORD,
	PP_VACUUM,
	FUEL_TANK_CENTER_LEVEL,
	FUEL_TANK_CENTER_CAPACITY,
	FUEL_TANK_LEFT_MAIN_LEVEL,
	FUEL_TANK_LEFT_MAIN_CAPACITY,
	FUEL_TANK_LEFT_AUX_LEVEL,
	FUEL_TANK_LEFT_AUX_CAPACITY,
	FUEL_TANK_LEFT_TIP_LEVEL,
	FUEL_TANK_LEFT_TIP_CAPACITY,
	FUEL_TANK_RIGHT_MAIN_LEVEL,
	FUEL_TANK_RIGHT_MAIN_CAPACITY,
	FUEL_TANK_RIGHT_AUX_LEVEL,
	FUEL_TANK_RIGHT_AUX_CAPACITY,
	FUEL_TANK_RIGHT_TIP_LEVEL,
	FUEL_TANK_RIGHT_TIP_CAPACITY,
	FUEL_QUANTITY_RIGHT,		//	Total Gallons
	FUEL_QUANTITY_LEFT,			//	Total Gallons
	FUEL_QUANTITY_CENTER,		//	Total Gallons
	FUEL_WEGHT_PER_GALLON,		//  in pounds I.F  (6 lbs/gal = 1536)
	FUEL_TANK_SELECTOR,			//  see FUEL_TANK_SELECTOR_ enum values
	CROSS_FEED_SELECTOR,		//	OFF, LEFT_TO_RIGHT, or RIGHT_TO_LEFT
	YOKE_POS_Y,					//  yoke Y position -16k=yoke pushed full in
	YOKE_IND_Y,					//  yoke Y position -16k=yoke pushed full in
	YOKE_POS_X,					//  aileron -16k=yoke turned full left
	YOKE_IND_X,					//  aileron -16k=yoke turned full left
	AILERON_POS,				//  Aileron Position -16k=full left ?
	RUDDER_PEDAL_POS,			//  rudder pedals -16k=left pedal pushed full in
	RUDDER_PEDAL_IND,			//  rudder -16k=left pedal pushed full in
	RUDDER_POS,					//  Rudder Position -16k=full left ?
	ELEVATOR_POS,				//  Elevator Position -16k=down full
	ELEVATOR_TRIM_POS,			//  elevator trim position -16k=full nose down
	ELEVATOR_TRIM_IND,			//  elevator trim position -16k=full nose down
	BRAKES_LEFT_POS,			//  0=off 32k=full brakes
	BRAKES_RIGHT_POS,			//  0=off 32k=full brakes
	BRAKE_IND,					//  0=off 16k=full brakes
	PARKING_BRAKE_POS,			//  0=off 32k=full	parking brakes	
	SPOILERS_ARMED,
	SPOILERS_HANDLE_POS,
	SPOILERS_POS_LEFT,	
	SPOILERS_POS_RIGHT,	
	FLAPS_HANDLE_POS,
	FLAPS_POS_LEFT,	
	FLAPS_POS_RIGHT,	
	GEAR_HANDLE_POS,
	GEAR_POS_NOSE,	
	GEAR_POS_LEFT,	
	GEAR_POS_RIGHT,
	DISPLAY_UNITS,				//  english vs. metric system
	SIM_SPEED,					//  time dilation factor for sim equations
	ZOOM_FACTOR,				//	zoom value of current window in real units
	REALISM_SENSE,
	REALISM_SYSTEMS,
	RELIABILITY_SENSE,			//  0 = unreliable - 100 = totally reliable
	AMBIENT_TEMP_DEGREES_C,		// 	15 deg C = 59 deg F (1/256 deg Celsius = 1 unit)
	AMBIENT_PRES_MBAR,			//  1013.2 mb = 29.92 in Hg (1/16 mb = 1 unit)
	AMBIENT_WIND_VEL,			//  current wind velocity (knots)
	AMBIENT_WIND_DIR,			//  current wind direction
	AMBIENT_WINDE,				//  east wind component i.f m/sec units
	AMBIENT_WINDN,				//  north wind component i.f m/sec units
	AMBIENT_WINDA,				//  alt wind component i.f m/sec units
	BAROMETRIC_PRESSURE,		//	barometric pressure experienced
	ANGLE_OF_ATTACK_INDICATOR,
	TOTAL_AIR_TEMP,
	G_FORCE,
	CHARGING_AMPS,				//  charging system amps - 1 amp=65535
	SUCTION_PRESSURE,			//	in hg
	MARKER_BEACON_STATE,		//	0=no beacon, 1=outer, 2=middle, 3=inner
	CURRENT_DME,				//  DMECUR_DME1 or DMECUR_DME2
} GAUGE_TOKEN;


typedef	enum	VAR_TYPE {
	VAR_TYPE_NONE,

	TYPE_BOOL8,
	TYPE_UINT8,
	TYPE_SINT8,
	TYPE_FLAGS8,
	TYPE_ENUM8,

	TYPE_BOOL16,
	TYPE_ANGL16,
	TYPE_UINT16,
	TYPE_SINT16,
	TYPE_UIF16,
	TYPE_SIF16,
	TYPE_FLAGS16,
	TYPE_ENUM16,
	TYPE_BCD16,
	TYPE_BCO16,
	TYPE_VAR16,

	TYPE_BOOL32,
	TYPE_ANGL32,
	TYPE_UINT32,
	TYPE_SINT32,
	TYPE_UIF32,
	TYPE_SIF32,
	TYPE_FLAGS32,
	TYPE_ENUM32,
	TYPE_VAR32,

	TYPE_ANGL48,
	TYPE_SINT48,
	TYPE_UIF48,
	TYPE_SIF48,

	TYPE_UINT64,
	TYPE_SINT64,
	TYPE_SIF64,
	TYPE_FLOAT64,

	TYPE_BOOL,
	TYPE_FLAGS,
	TYPE_ENUM,

	TYPE_VOID,
	TYPE_PVOID,

	TYPE_PUINT32,
	TYPE_PSINT32,
	TYPE_PFLOAT64,

	VAR_TYPE_MAX
} VAR_TYPE;

typedef union	UNIVERSAL_VAR {
		FLOAT64	n;		// any number
		BOOL	b;		// any boolean
		ENUM	e;		// any enumerated value
		FLAGS	f;		// any flags field
		PVOID	p;		// any pointer
		VAR32	d;		// any binary coded decimal
		VAR32	o;		// any binary coded octal
} UNIVERSAL_VAR, *PUNIVERSAL_VAR, **PPUNIVERSAL_VAR;

typedef struct	MODULE_VAR {
	GAUGE_TOKEN			id;
	PVOID				var_ptr;
	VAR_TYPE			var_type;
	UNIVERSAL_VAR		var_value;
	UNIVERSAL_VAR		var_old;		// value of global var last iteration
} MODULE_VAR, *PMODULE_VAR, **PPMODULE_VAR;




// defines for mouse sense rect stuff
typedef	enum
{
	MOUSE_RECT_EOL,
	MOUSE_RECT_PARENT,
	MOUSE_RECT_CHILD,
	MOUSE_RECT_END_PARENT,
} MOUSE_RECT_TYPE;

typedef	enum
{
	CURSOR_NONE = -1,
	CURSOR_NORMAL = 0,
	CURSOR_UPARROW,
	CURSOR_DOWNARROW,
	CURSOR_LEFTARROW,
	CURSOR_RIGHTARROW,
	CURSOR_HAND,
	CURSOR_CROSSHAIR,
} CURSOR_TYPE;

typedef	BOOL FSAPI	MOUSE_FUNCTION( PPIXPOINT relative_point, FLAGS32 mouse_flags );
typedef				MOUSE_FUNCTION		*PMOUSE_FUNCTION;

typedef	struct	MOUSERECT
{
	MOUSE_RECT_TYPE	rect_type;			// type of mouse rectangle (parent, child, eol)
	PIXBOX			relative_box;		// relative sense rectangle (relative to parameter to register function)
	CURSOR_TYPE		cursor;				// cursor to display when over this window
	ID				help_id;			// pop-up help id
	FLAGS			mouse_flags;		// types of mouse activities to look for
	ID				event_id;			// event to generate if mouse_flags is satisfied (implies simple mouse_flags)
	PMOUSE_FUNCTION	mouse_function;		// function to call if mouse_flag is satisfied
	PVOID			api_data;			// data for FS6API's use
} MOUSERECT, *PMOUSERECT, **PPMOUSERECT;


// Mouse rectangle macros
#define	MOUSE_PARENT_BEGIN( x, y, w, h, helpid )						{MOUSE_RECT_PARENT, {x, y, w, h}, CURSOR_NONE, helpid, MOUSE_NONE, 0, NULL, NULL},

#define	MOUSE_PARENT_END												{MOUSE_RECT_END_PARENT, {0, 0, 0, 0}, CURSOR_NONE, HELP_NONE, MOUSE_NONE, 0, NULL, NULL},

#define	MOUSE_PARENT( x, y, w, h, helpid )								MOUSE_PARENT_BEGIN( x, y, w, h, helpid )					\
																		MOUSE_PARENT_END

#define	MOUSE_BEGIN( name, helpid, x, y )								MOUSERECT	name[]	= {										\
																		MOUSE_PARENT_BEGIN( x, y, 0, 0, helpid )

#define	MOUSE_END														MOUSE_PARENT_END											\
																		{MOUSE_RECT_EOL, {0, 0, 0, 0}, CURSOR_NONE, HELP_NONE, MOUSE_NONE, 0, NULL, NULL}};

#define	MOUSE_CHILD_EVENT( x, y, w, h, cursor, mouse_flags, event_id )	{MOUSE_RECT_CHILD, {x, y, w, h}, cursor, HELP_NONE, mouse_flags, event_id, NULL, NULL},
#define	MOUSE_CHILD_FUNCT( x, y, w, h, cursor, mouse_flags, function )	{MOUSE_RECT_CHILD, {x, y, w, h}, cursor, HELP_NONE, mouse_flags, 0, function, NULL},


#define	MOUSE_RIGHTSINGLE	BIT31
#define	MOUSE_MIDDLESINGLE	BIT30
#define	MOUSE_LEFTSINGLE	BIT29
#define	MOUSE_RIGHTDOUBLE	BIT28
#define	MOUSE_MIDDLEDOUBLE	BIT27
#define	MOUSE_LEFTDOUBLE	BIT26
#define	MOUSE_RIGHTDRAG		BIT25
#define	MOUSE_MIDDLEDRAG	BIT24
#define	MOUSE_LEFTDRAG		BIT23
#define	MOUSE_MOVE			BIT22
#define	MOUSE_DOWN_REPEAT	BIT21
#define	MOUSE_KEYBOARD		BIT20

#define	MOUSE_NONE			0

#define	HELP_NONE			0			// move this somewhere else - temp here for now



#define	HINSTANCE	PVOID

// Gauge functions
typedef	void FSAPI	QUERY_ROUTINE( void );
typedef		QUERY_ROUTINE		*PQUERY_ROUTINE;

typedef	void FSAPI	INSTALL_ROUTINE( HINSTANCE resource_file_handle );
typedef		INSTALL_ROUTINE		*PINSTALL_ROUTINE;

typedef	void FSAPI	INITIALIZE_ROUTINE( void );
typedef		INITIALIZE_ROUTINE		*PINITIALIZE_ROUTINE;

typedef	void FSAPI	UPDATE_ROUTINE( void );
typedef		UPDATE_ROUTINE		*PUPDATE_ROUTINE;

typedef	enum	GENERATE_PHASE
{
	GENERATE_FX_ERASE,
	GENERATE_FX_PLOT,
	GENERATE_IMAGE_RECALC
} GENERATE_PHASE, *PGENERATE_PHASE;

typedef	void FSAPI	GENERATE_ROUTINE( GENERATE_PHASE phase );
typedef		GENERATE_ROUTINE		*PGENERATE_ROUTINE;

typedef	void FSAPI	DRAW_ROUTINE( void );
typedef		DRAW_ROUTINE		*PDRAW_ROUTINE;

typedef	void FSAPI	KILL_ROUTINE( void );
typedef		KILL_ROUTINE		*PKILL_ROUTINE;


// Callback functions
typedef	FLOAT64 FSAPI	FN_FLOAT64	( FLOAT64	val );
typedef			FN_FLOAT64	*PFN_FLOAT64;

typedef	FLOAT64 FSAPI	MODULE_VAR_CB	( PMODULE_VAR	val );
typedef			MODULE_VAR_CB	*PMODULE_VAR_CB;


// Seqsel Selection stuff
#define	SELECT_NONE					0
#define	SELECT_1					1
#define	SELECT_ZOOM					2
#define	SELECT_MAGNETO				3
#define	SELECT_COM_WHOLE			4
#define	SELECT_COM_FRACTION			5
#define	SELECT_NAV1_WHOLE			6
#define	SELECT_NAV1_FRACTION		7
#define	SELECT_NAV2_WHOLE			8
#define	SELECT_NAV2_FRACTION		9
#define	SELECT_XPNDR_1000			10
#define	SELECT_XPNDR_0100			11
#define	SELECT_XPNDR_0010			12
#define	SELECT_XPNDR_0001			13
#define	SELECT_VOR1					14
#define	SELECT_VOR2					15
#define	SELECT_ENGINE				16
#define	SELECT_DME1					17
#define	SELECT_DME2					18
#define	SELECT_ADF_100				19
#define	SELECT_ADF_010				20
#define	SELECT_ADF_001				21
#define	SELECT_EGT_BUG				22
#define	SELECT_SIM_RATE				23
#define SELECT_CLOCK_HOURS			24
#define SELECT_CLOCK_MINUTES		25
#define	SELECT_CLOCK_SECONDS		26
#define	SELECT_STANDBY_COM_WHOLE	27
#define	SELECT_STANDBY_COM_FRACTION	28
#define	SELECT_STANDBY_NAV_WHOLE	29
#define	SELECT_STANDBY_NAV_FRACTION	30
#define	SELECT_STANDBY_ADF_100		31
#define	SELECT_STANDBY_ADF_010		32
#define	SELECT_STANDBY_ADF_001		33

// used for the image_flags field
#define		IMAGE_USE_TRANSPARENCY		BIT0	//	these don't change dynamically and are set
#define		IMAGE_USE_ERASE				BIT1	//	in the gauge file
#define		IMAGE_USE_BRIGHT			BIT2	//
#define		IMAGE_NO_STATIC_BLENDING	BIT4	//	only valid on static_images using
												//	IMAGE_USE_TRANSPARENCY and first element in list

#define		IMAGE_HIDDEN				BIT30	// these change dynamically
#define		IMAGE_ON_SCREEN				BIT31


#define		GET_IMAGE_HIDDEN( element )			((element)->image_flags & IMAGE_HIDDEN)
#define		SHOW_IMAGE( element )				((element)->image_flags &= ~IMAGE_HIDDEN)
#define		HIDE_IMAGE( element )				((element)->image_flags |= IMAGE_HIDDEN)

#define		GET_USE_TRANSPARENCY( element )		((element)->image_flags & IMAGE_USE_TRANSPARENCY)
#define		GET_USE_ERASE( element )			((element)->image_flags & IMAGE_USE_ERASE)
#define		GET_USE_BRIGHT( element )			((element)->image_flags & IMAGE_USE_BRIGHT)

#define		GET_ON_SCREEN( element )			((element)->image_flags & IMAGE_ON_SCREEN)
#define		SET_ON_SCREEN( element )			((element)->image_flags |= IMAGE_ON_SCREEN)
#define		SET_OFF_SCREEN( element )			((element)->image_flags &= ~IMAGE_ON_SCREEN)


typedef enum ELEMENT_TYPE_ENUM {
	ELEMENT_TYPE_STATIC_IMAGE,
	ELEMENT_TYPE_NEEDLE,
	ELEMENT_TYPE_STRING,
	ELEMENT_TYPE_SLIDER,
	ELEMENT_TYPE_ICON,
	ELEMENT_TYPE_MOVING_IMAGE,
	ELEMENT_TYPE_SPRITE
} ELEMENT_TYPE_ENUM;


#define	ASI_ALT_MANUALLY_TUNABLE			BIT0
#define ASI_HEADING_MANUALLY_TUNABLE		BIT1


typedef struct NONLINEARITY
{
	PIXPOINT	pt;
	FLOAT64		value;
	FLOAT64		degrees;
} NONLINEARITY, *PNONLINEARITY, **PPNONLINEARITY;

typedef	enum	FAILURE_KEY
{
	FAIL_NONE = 0,

	FAIL_SYSTEM_ELECTRICAL,
	FAIL_SYSTEM_ENGINE,
	FAIL_SYSTEM_PITOT_STATIC,
	FAIL_SYSTEM_VACUUM,

	FAIL_GAUGE_ADF,
	FAIL_GAUGE_AIRSPEED,
	FAIL_GAUGE_ALTIMETER,
	FAIL_GAUGE_ATTITUDE,
	FAIL_GAUGE_COMMUNICATIONS,
	FAIL_GAUGE_FUEL_INDICATORS,
	FAIL_GAUGE_GYRO_HEADING,
	FAIL_GAUGE_MAGNETIC_COMPASS,
	FAIL_GAUGE_NAVIGATION,			// this assumes no vors
	FAIL_GAUGE_NAVIGATION_VOR1,		// only vor1
	FAIL_GAUGE_NAVIGATION_VOR2,		// only vor2
	FAIL_GAUGE_NAVIGATION_BOTH,		// both vors
	FAIL_GAUGE_TRANSPONDER,
	FAIL_GAUGE_TURN_COORDINATOR,
	FAIL_GAUGE_VERTICAL_SPEED,

	FAIL_KEY_MAX	
} FAILURE_KEY, *PFAILURE_KEY, **PPFAILURE_KEY;

typedef	enum	FAILURE_ACTION
{
	FAIL_ACTION_NONE = 0,
	FAIL_ACTION_FREEZE,
	FAIL_ACTION_ZERO,
	FAIL_ACTION_NO_DRAW,
	FAIL_ACTION_COVER,

	FAIL_ACTION_MAX
} FAILURE_ACTION, *PFAILURE_ACTION, **PPFAILURE_ACTION;

typedef	struct	FAILURE_RECORD
{
	FAILURE_KEY		key;
	FAILURE_ACTION	action;
	PENUM8			var;
} FAILURE_RECORD, *PFAILURE_RECORD, **PPFAILURE_RECORD;


typedef struct ELEMENT_HEADER *PELEMENT_HEADER, **PPELEMENT_HEADER;

#define		GAUGE_HEADER_VERSION		610
typedef struct	GAUGEHDR
{
	UINT32				gauge_header_version;	// header version number
	char				*gauge_name;			//
	PPELEMENT_HEADER	elements_list;			// list of elements in gauge
	PQUERY_ROUTINE		query_routine;			// HACKHACK
	PINSTALL_ROUTINE	install_routine;		// gauge installation routine
	PINITIALIZE_ROUTINE	initialize_routine;
	PUPDATE_ROUTINE		update_routine;			// gauge routine for gauge update
	PGENERATE_ROUTINE	generate_routine;		// gauge re-initialization routine
	PDRAW_ROUTINE		draw_routine;
	PKILL_ROUTINE		kill_routine;			// gauge shutdown routine
	PVOID				reserved_1;
	UINT32				size_x_mm;				// actual gauge size
	char				reserved_2[36];
} GAUGEHDR, *PGAUGEHDR, **PPGAUGEHDR;


typedef	struct	IMAGE_SET
{
	PIMAGE	final;
	char	reserved_1[12];
} IMAGE_SET, *PIMAGE_SET, **PPIMAGE_SET;



#define	ELEMENT_INFO	ELEMENT_TYPE_ENUM			element_type;		\
						ID							resource_id;		\
						PIXPOINT					position;			\
						PIXPOINT					previous_position;	\
						PIXPOINT					ofs;				\
						PGAUGEHDR					gauge_header;		\
						struct ELEMENT_HEADER		*previous_element;	\
						struct ELEMENT_HEADER		**next_element;		\
						PFAILURE_RECORD				failure_systems;	\
						FLAGS						image_flags;		\
						FLAGS						aircraft_special_instrumentation;\
						FLAGS						reserved;



typedef struct ELEMENT_HEADER
{
	ELEMENT_INFO
} ELEMENT_HEADER, *PELEMENT_HEADER, **PPELEMENT_HEADER;


#define HEADER union\
			{\
				struct\
				{\
					ELEMENT_INFO\
				};\
				ELEMENT_HEADER		header;\
			}


typedef struct ELEMENT_STATIC_IMAGE
{
	HEADER;

	IMAGE_SET		image_data;
	PIMAGE			save_buffer;
} ELEMENT_STATIC_IMAGE, *PELEMENT_STATIC_IMAGE, **PPELEMENT_STATIC_IMAGE;

typedef struct ELEMENT_NEEDLE
{
	HEADER;

	MODULE_VAR		source_var;				// global variable
	PMODULE_VAR_CB	source_var_cb;

	PFN_FLOAT64		display_value_fn;		// convert from global var to displayed value
	PFN_FLOAT64		angle_fn;				// convert from display goal to theta
	PFN_FLOAT64		lag_fn;					// function to add lag
	PIXPOINT		reference;				// intial point to calculate to check for changes
	PNONLINEARITY	nonlinearity_table;		
	UINT32			nonlinearity_table_size;
	SINT32			max_degrees_per_tick;

	FLOAT64			readout_goal;			// desired displayed value

	FLOAT64			theta_goal;				// goal angle

	FLOAT64			theta;					// needle rotation

	PIXPOINT		reference_old;			// old

	PIXPOINT		o0, o1, o2, o3;			// offsets of the four corners of the image

	IMAGE_SET		needle_data;			// pointer to image data

	PIMAGE			texture_data;
	UINT32			texture_handle;

	PIMAGE			save_buffer;
	PIXPOINT		save_position;
} ELEMENT_NEEDLE, *PELEMENT_NEEDLE, **PPELEMENT_NEEDLE;




typedef struct SEQ_REC
{
	int seq_id;
	int sel_str;
	int sel_end;
} SEQ_REC, *PSEQ_REC, **PPSEQ_REC;

#define		COLORREF	unsigned long
#define		HDC			unsigned long
#define		HFONT		unsigned long
#define		HBITMAP		unsigned long
#define		HBRUSH		unsigned long

typedef struct ELEMENT_STRING
{
	HEADER;

	MODULE_VAR		source_var[3];
	FLOAT64			save_var[3];
	PMODULE_VAR_CB	source_var_cb[3];
	PFN_FLOAT64		source_fn;

	PCHAR			string;
	PCHAR			string_old;

	PIXPOINT		img_size;
	PIMAGE			string_data;
	PIMAGE			save_buffer;

	COLORREF		fg_color;
	COLORREF		bg_color;
	COLORREF		hilite_color;

	HDC				hdc;					// HDC for Win32 API DrawText

	HFONT			hfont;					// Win32 font object
	HFONT			hfont_old;

	HBITMAP			hbmp;					// DibSection for Win32 API DrawText
	HBITMAP			hbmp_old;

	HBRUSH			hbrush;
	HBRUSH			hbrush_old;

	char			font_name[32];
	long			font_weight;
	UINT8			font_charset;
	UINT32			draw_text_flags;
	UINT16			max_string_length;
	UINT16			char_width;
	SINT16			sel_str;
	SINT16			sel_end;
	PSEQ_REC		seq;
	int				save_global_seq;
} ELEMENT_STRING, *PELEMENT_STRING, **PPELEMENT_STRING;


#define STR_UNSEL(ELEMENT)				ELEMENT->sel_end = -1; ELEMENT->sel_str = -1;
#define STR_SEL(ELEMENT, STR, END)		ELEMENT->sel_end = END; ELEMENT->sel_str = STR;
#define IS_STR_SEL(ELEMENT)				(ELEMENT->sel_end != -1 && ELEMENT->sel_str != -1)

typedef struct ELEMENT_SLIDER
{
	HEADER;

	MODULE_VAR		source_var_x;
	PMODULE_VAR_CB	source_var_x_cb;
	FLOAT64			scale_x;
	PFN_FLOAT64		lag_fn_x;

	MODULE_VAR		source_var_y;
	PMODULE_VAR_CB	source_var_y_cb;
	FLOAT64			scale_y;
	PFN_FLOAT64		lag_fn_y;

	IMAGE_SET		slider_data;

	PIMAGE			save_buffer;
} ELEMENT_SLIDER, *PELEMENT_SLIDER, **PPELEMENT_SLIDER;


// Icon Switch Types
#define ICON_SWITCH_TYPE_SET_CUR_ICON				0
#define ICON_SWITCH_TYPE_SET_CUR_USING_RANGE		1
#define ICON_SWITCH_TYPE_STEP_TO					3
#define ICON_SWITCH_TYPE_STEP_TO_USING_RANGE		4

typedef struct ELEMENT_ICON
{
	HEADER;

	MODULE_VAR		source_var;
	PMODULE_VAR_CB	source_var_cb;

	long			switch_type;
	long			switch_count;

	FLOAT64			scale;
	long			offset;

	long			num_icons;
	long			cur_icon;
	long			dst_icon;

	PIMAGE_SET		picon_data;

	PIMAGE			save_buffer;
} ELEMENT_ICON, *PELEMENT_ICON, **PPELEMENT_ICON;

typedef struct ELEMENT_MOVING_IMAGE
{
	HEADER;

	MODULE_VAR		source_var_x;
	PMODULE_VAR_CB	source_var_x_cb;
	FLOAT64			min_x;
	FLOAT64			max_x;
	PFN_FLOAT64		lag_x;

	MODULE_VAR		source_var_y;
	PMODULE_VAR_CB	source_var_y_cb;
	FLOAT64			min_y;
	FLOAT64			max_y;
	PFN_FLOAT64		lag_y;

	FLOAT64			scale_x;
	FLOAT64			scale_y;
	FLOAT64			offset_x;
	FLOAT64			offset_y;

	PIXPOINT		save_position;

	IMAGE_SET		image_data;	
	IMAGE_SET		local_mask_data;

	PIMAGE			mask_data;
	PIMAGE			save_buffer;
} ELEMENT_MOVING_IMAGE, *PELEMENT_MOVING_IMAGE, **PPELEMENT_MOVING_IMAGE;

typedef struct ELEMENT_SPRITE
{
	HEADER;

	MODULE_VAR		source_var_x;
	PMODULE_VAR_CB	source_var_x_cb;
	FLOAT64			scale_x;

	MODULE_VAR		source_var_y;
	PMODULE_VAR_CB	source_var_y_cb;
	FLOAT64			scale_y;

	MODULE_VAR		source_var_0;
	PMODULE_VAR_CB	source_var_0_cb;
	FLOAT64			scale_0;

	float			texture_scale_x;
	float			texture_scale_y;

	PIXPOINT		reference;				// intial point to calculate to check for changes

	PIXPOINT		reference_old;			// old

	PIXPOINT		o0, o1, o2, o3;			// offsets of the four corners of the image used to calculate uv coords
	PIXPOINT		os0, os1, os2, os3;		// screen coordinates of the four corners

	IMAGE_SET		sprite_data;

	PIMAGE			texture_data;
	UINT32			texture_handle;

	IMAGE_SET		local_mask_data;	
	PIMAGE			mask_data;
	PIMAGE			save_buffer;
} ELEMENT_SPRITE, *PELEMENT_SPRITE, **PPELEMENT_SPRITE;



//***************************************************************************/
//	Element Definition Macros
//***************************************************************************/
#define	MAKE_STATIC(	NAME,														\
						RES_ID,														\
						NEXT_LIST,													\
						FAILURE,													\
						DRAW_FLAGS,													\
						ASI_FLAGS,													\
						POSITION_X, POSITION_Y )									\
																					\
	ELEMENT_STATIC_IMAGE		NAME	=											\
	{																				\
		ELEMENT_TYPE_STATIC_IMAGE,													\
		RES_ID,																		\
		POSITION_X, POSITION_Y,														\
		{0,0},																		\
		{0,0},																		\
		&gauge_header,																\
		NULL,																		\
		(PPELEMENT_HEADER)(NEXT_LIST),												\
		(PFAILURE_RECORD)(FAILURE),													\
		DRAW_FLAGS,																	\
		ASI_FLAGS,																	\
		0																			\
	};


//***************************************************************************/
#define	MAKE_NEEDLE(	NAME,														\
						RES_ID,														\
						NEXT_LIST,													\
						FAILURE,													\
						DRAW_FLAGS,													\
						ASI_FLAGS,													\
						BKND_POSITION_X, BKND_POSITION_Y,							\
						NDL_POSITION_X, NDL_POSITION_Y,								\
						REFERENCE_X, REFERENCE_Y,									\
						SOURCE_VAR, CALLBACK,										\
						NONLINEARITY_TABLE,											\
						MAX_DEG_PER_SEC )											\
																					\
	ELEMENT_NEEDLE				NAME	=											\
	{																				\
		ELEMENT_TYPE_NEEDLE,														\
		RES_ID,																		\
		BKND_POSITION_X, BKND_POSITION_Y,											\
		{0,0},																		\
		NDL_POSITION_X, NDL_POSITION_Y,												\
		&gauge_header,																\
		NULL,																		\
		(PPELEMENT_HEADER)(NEXT_LIST),												\
		(PFAILURE_RECORD)(FAILURE),													\
		DRAW_FLAGS,																	\
		ASI_FLAGS,																	\
		0,																			\
																					\
		{SOURCE_VAR},																\
		CALLBACK,																	\
		NULL,																		\
		NULL,																		\
		NULL,																		\
		REFERENCE_X, REFERENCE_Y,													\
		NONLINEARITY_TABLE,															\
		sizeof( NONLINEARITY_TABLE )/sizeof( NONLINEARITY ),						\
		MAX_DEG_PER_SEC																\
	};


//***************************************************************************/
#define	MAKE_STRING(	NAME,														\
						NEXT_LIST,													\
						FAILURE,													\
						DRAW_FLAGS,													\
						ASI_FLAGS,													\
						POSITION_X, POSITION_Y,										\
						SIZE_X, SIZE_Y,												\
						NUM_CHARS,													\
						SOURCE_VAR_1, CALLBACK_1,									\
						SOURCE_VAR_2, CALLBACK_2,									\
						SOURCE_VAR_3, CALLBACK_3,									\
						STRING_CALLBACK,											\
						FORECOLOR,													\
						BACKCOLOR,													\
						HILITECOLOR,												\
						FONT_NAME,													\
						FONT_WEIGHT,												\
						FONT_CHARSET,												\
						HILITE_LIST )												\
																					\
	ELEMENT_STRING				NAME	=											\
    {																				\
		ELEMENT_TYPE_STRING,														\
		-1,																			\
		POSITION_X, POSITION_Y,														\
		{0,0},																		\
		{0,0},																		\
		&gauge_header,																\
		NULL,																		\
		(PPELEMENT_HEADER)(NEXT_LIST),												\
		(PFAILURE_RECORD)(FAILURE),													\
		DRAW_FLAGS,																	\
		ASI_FLAGS,																	\
		0,																			\
																					\
		{{SOURCE_VAR_1}, {SOURCE_VAR_2}, {SOURCE_VAR_3}},							\
		{0, 0, 0},																	\
		{CALLBACK_1, CALLBACK_2, CALLBACK_3},										\
		STRING_CALLBACK,															\
		NULL,																		\
		NULL,																		\
		SIZE_X, SIZE_Y,																\
		NULL,																		\
		NULL,																		\
		FORECOLOR,																	\
		BACKCOLOR,																	\
		HILITECOLOR,																\
		0,																			\
		0,																			\
		0,																			\
		0,																			\
		0,																			\
		0,																			\
		0,																			\
		FONT_NAME,																	\
		FONT_WEIGHT,																\
		FONT_CHARSET,																\
		DT_CENTER | DT_VCENTER | DT_SINGLELINE,										\
		NUM_CHARS,																	\
		0,																			\
		0,																			\
		0,																			\
		HILITE_LIST																	\
	};


//***************************************************************************/
#define	MAKE_SLIDER(	NAME,														\
						RES_ID,														\
						NEXT_LIST,													\
						FAILURE,													\
						DRAW_FLAGS,													\
						ASI_FLAGS,													\
						POSITION_X, POSITION_Y,										\
						SOURCE_VAR_X, CALLBACK_X, SCALE_X,							\
						SOURCE_VAR_Y, CALLBACK_Y, SCALE_Y )							\
																					\
	ELEMENT_SLIDER				NAME	=											\
	{																				\
		ELEMENT_TYPE_SLIDER,														\
		RES_ID,																		\
		POSITION_X, POSITION_Y,														\
		{0,0},																		\
		{0,0},																		\
		&gauge_header,																\
		NULL,																		\
		(PPELEMENT_HEADER)(NEXT_LIST),												\
		(PFAILURE_RECORD)(FAILURE),													\
		DRAW_FLAGS,																	\
		ASI_FLAGS,																	\
		0,																			\
																					\
		{SOURCE_VAR_X},																\
		CALLBACK_X,																	\
		SCALE_X,																	\
		NULL,																		\
		{SOURCE_VAR_Y},																\
		CALLBACK_Y,																	\
		SCALE_Y,																	\
		NULL																		\
	};


//***************************************************************************/
#define	MAKE_ICON(		NAME,														\
						RES_ID,														\
						NEXT_LIST,													\
						FAILURE,													\
						DRAW_FLAGS,													\
						ASI_FLAGS,													\
						POSITION_X, POSITION_Y,										\
						SOURCE_VAR, CALLBACK,										\
						SWITCH_TYPE,												\
						NUM_ICONS,													\
						SCALE,														\
						OFFSET )													\
																					\
    ELEMENT_ICON				NAME	=											\
    {																				\
    	ELEMENT_TYPE_ICON,															\
    	RES_ID,																		\
    	POSITION_X, POSITION_Y,														\
    	{0,0},																		\
    	{0,0},																		\
    	&gauge_header,																\
    	NULL,																		\
    	(PPELEMENT_HEADER)(NEXT_LIST),												\
    	(PFAILURE_RECORD)(FAILURE),													\
    	DRAW_FLAGS,																	\
    	ASI_FLAGS,																	\
    	0,																			\
																					\
		{SOURCE_VAR},																\
		CALLBACK,																	\
		SWITCH_TYPE,																\
		0,																			\
		SCALE,																		\
		OFFSET,																		\
		NUM_ICONS																	\
    };


//***************************************************************************/
#define	MAKE_MOVING(	NAME,														\
						RES_ID,														\
						NEXT_LIST,													\
						FAILURE,													\
						DRAW_FLAGS,													\
						ASI_FLAGS,													\
						POSITION_X, POSITION_Y,										\
						SOURCE_VAR_X, CALLBACK_X,									\
						MIN_X, MAX_X,												\
						SOURCE_VAR_Y, CALLBACK_Y,									\
						MIN_Y, MAX_Y )												\
																					\
	ELEMENT_MOVING_IMAGE		NAME	=											\
	{																				\
		ELEMENT_TYPE_MOVING_IMAGE,													\
		RES_ID,																		\
		POSITION_X, POSITION_Y,														\
		{0,0},																		\
		{0,0},																		\
		&gauge_header,																\
		NULL,																		\
		(PPELEMENT_HEADER)(NEXT_LIST),												\
		(PFAILURE_RECORD)(FAILURE),													\
		DRAW_FLAGS,																	\
		ASI_FLAGS,																	\
		0,																			\
																					\
		{SOURCE_VAR_X},																\
		CALLBACK_X,																	\
		MIN_X,																		\
		MAX_X,																		\
		NULL,																		\
		{SOURCE_VAR_Y},																\
		CALLBACK_Y,																	\
		MIN_Y,																		\
		MAX_Y,																		\
		NULL																		\
	};


//***************************************************************************/
#define	MAKE_SPRITE(	NAME,														\
						RES_ID,														\
						NEXT_LIST,													\
						FAILURE,													\
						DRAW_FLAGS,													\
						ASI_FLAGS,													\
						BKND_POSITION_X, BKND_POSITION_Y,							\
						TEXTURE_CENTER_X, TEXTURE_CENTER_Y,							\
						TEXTURE_SCALE_X, TEXTURE_SCALE_Y,							\
						REFERENCE_X, REFERENCE_Y,									\
						SOURCE_VAR_X, CALLBACK_X, SCALE_X,							\
						SOURCE_VAR_Y, CALLBACK_Y, SCALE_Y,							\
						SOURCE_VAR_0, CALLBACK_0, SCALE_0 )							\
																					\
	ELEMENT_SPRITE				NAME	=											\
	{																				\
		ELEMENT_TYPE_SPRITE,														\
		RES_ID,																		\
		BKND_POSITION_X, BKND_POSITION_Y,											\
		{0,0},																		\
		TEXTURE_CENTER_X, TEXTURE_CENTER_Y,											\
		&gauge_header,																\
		NULL,																		\
		(PPELEMENT_HEADER)(NEXT_LIST),												\
		(PFAILURE_RECORD)(FAILURE),													\
		DRAW_FLAGS,																	\
		ASI_FLAGS,																	\
		0,																			\
																					\
		{SOURCE_VAR_X},																\
		CALLBACK_X,																	\
		SCALE_X,																	\
		{SOURCE_VAR_Y},																\
		CALLBACK_Y,																	\
		SCALE_Y,																	\
		{SOURCE_VAR_0},																\
		CALLBACK_0,																	\
		SCALE_0,																	\
		(float)TEXTURE_SCALE_X, (float)TEXTURE_SCALE_Y,								\
		REFERENCE_X, REFERENCE_Y													\
	};

//***************************************************************************/
//***************************************************************************/



// Module Export Structure
typedef struct  PANELS
{
	char	 reserved1[15*4];
	void	 (FSAPI *element_query)( PELEMENT_HEADER element );
	void	 (FSAPI *element_install)( PELEMENT_HEADER element, PVOID resource_file_handle );
	void	 (FSAPI *element_initialize)( PELEMENT_HEADER element );
	void	 (FSAPI *element_update)( PELEMENT_HEADER element );
	void	 (FSAPI *element_generate)( PELEMENT_HEADER element, GENERATE_PHASE phase );
	void	 (FSAPI *element_plot)( PELEMENT_HEADER element );
	void	 (FSAPI *element_erase)( PELEMENT_HEADER element );
	void	 (FSAPI *element_kill)( PELEMENT_HEADER element );
	PELEMENT_HEADER		 (FSAPI *element_create)( ELEMENT_TYPE_ENUM type );
	void	 (FSAPI *element_list_query)( PELEMENT_HEADER element );
	void	 (FSAPI *element_list_install)( PELEMENT_HEADER element, PVOID resource_file_handle );
	void	 (FSAPI *element_list_initialize)( PELEMENT_HEADER element );
	void	 (FSAPI *element_list_update)( PELEMENT_HEADER element );
	void	 (FSAPI *element_list_generate)( PELEMENT_HEADER element, GENERATE_PHASE phase );
	void	 (FSAPI *element_list_plot)( PELEMENT_HEADER element );
	void	 (FSAPI *element_list_erase)( PELEMENT_HEADER element );
	void	 (FSAPI *element_list_kill)( PELEMENT_HEADER element );
	void	 (FSAPI *mouse_list_install)( PMOUSERECT rect, PGAUGEHDR gauge_header, PPIXPOINT size );
	void	 (FSAPI *mouse_list_register)( PMOUSERECT rect, PGAUGEHDR gauge_header );
	void	 (FSAPI *mouse_list_unregister)( PMOUSERECT rect, PGAUGEHDR gauge_header );
	BOOL	 (FSAPI *panel_window_toggle)(UINT32 panel_id);
	ERR		 (FSAPI *trigger_key_event)( ID32 event_id, UINT32 value );
	void	 (FSAPI *register_var_by_name)( PVOID var, VAR_TYPE var_type, PSTRINGZ name );
	void	 (FSAPI *initialize_var)( PMODULE_VAR module_var );
	void	 (FSAPI *initialize_var_by_name)( PMODULE_VAR module_var, PSTRINGZ name );
	void	 (FSAPI *lookup_var)( PMODULE_VAR module_var );
	void	 (FSAPI *unregister_var_by_name)( PSTRINGZ name );
	void	 (FSAPI *unregister_all_named_vars)( void );
} PANELS, *PPANELS, **PPPANELS;


// This is the module's import table definition
typedef struct GAUGESIMPORT
{
	struct
	{
		ID			fnID;
		PPANELS		fnptr;
	}PANELSentry;

	struct
	{
		ID			fnID;
		PVOID		fnptr;
	}dummyentry;
} GAUGESIMPORT, *PGAUGESIMPORT;

__declspec(dllexport) GAUGESIMPORT ImportTable;


// This is the module's export table definition
typedef struct  GAUGES
{
	ID				ModuleID;
	void			(FSAPI *ModuleInit)(void);
	void			(FSAPI *ModuleDeinit)(void);
	FLAGS32			ModuleFlags;
	UINT32			ModulePriority;
	PVOID			DialogTable;
	PGAUGEHDR		gauge_header_ptr;
} GAUGES, *PGAUGES, **PPGAUGES;

__declspec(dllexport)	GAUGES			Linkage;



#define element_query				(ImportTable.PANELSentry.fnptr->element_query)
#define element_install				(ImportTable.PANELSentry.fnptr->element_install)
#define element_initialize			(ImportTable.PANELSentry.fnptr->element_initialize)
#define element_update				(ImportTable.PANELSentry.fnptr->element_update)
#define element_generate			(ImportTable.PANELSentry.fnptr->element_generate)
#define element_plot				(ImportTable.PANELSentry.fnptr->element_plot)
#define element_erase				(ImportTable.PANELSentry.fnptr->element_erase)
#define element_kill				(ImportTable.PANELSentry.fnptr->element_kill)
#define element_create				(ImportTable.PANELSentry.fnptr->element_create)
#define element_list_query			(ImportTable.PANELSentry.fnptr->element_list_query)
#define element_list_install		(ImportTable.PANELSentry.fnptr->element_list_install)
#define element_list_initialize		(ImportTable.PANELSentry.fnptr->element_list_initialize)
#define element_list_update			(ImportTable.PANELSentry.fnptr->element_list_update)
#define element_list_generate		(ImportTable.PANELSentry.fnptr->element_list_generate)
#define element_list_plot			(ImportTable.PANELSentry.fnptr->element_list_plot)
#define element_list_erase			(ImportTable.PANELSentry.fnptr->element_list_erase)
#define element_list_kill			(ImportTable.PANELSentry.fnptr->element_list_kill)
#define mouse_list_install			(ImportTable.PANELSentry.fnptr->mouse_list_install)
#define mouse_list_register			(ImportTable.PANELSentry.fnptr->mouse_list_register)
#define mouse_list_unregister		(ImportTable.PANELSentry.fnptr->mouse_list_unregister)
#define panel_window_toggle			(ImportTable.PANELSentry.fnptr->panel_window_toggle)
#define trigger_key_event			(ImportTable.PANELSentry.fnptr->trigger_key_event)
#define register_var_by_name		(ImportTable.PANELSentry.fnptr->register_var_by_name)
#define initialize_var				(ImportTable.PANELSentry.fnptr->initialize_var)
#define initialize_var_by_name		(ImportTable.PANELSentry.fnptr->initialize_var_by_name)
#define lookup_var					(ImportTable.PANELSentry.fnptr->lookup_var)
#define unregister_var_by_name		(ImportTable.PANELSentry.fnptr->unregister_var_by_name)
#define unregister_all_named_vars	(ImportTable.PANELSentry.fnptr->unregister_all_named_vars)


QUERY_ROUTINE		query_routine;
INSTALL_ROUTINE		install_routine;
INITIALIZE_ROUTINE	initialize_routine;
UPDATE_ROUTINE		update_routine;
GENERATE_ROUTINE	generate_routine;
DRAW_ROUTINE		draw_routine;
KILL_ROUTINE		kill_routine;



// MODULE_SETUP macro to define import and export tables, gauge header and other stuff
#define	MODULE_SETUP( version, size, name, element_list)		\
		extern	GAUGEHDR	gauge_header;						\
		void FSAPI	module_init(void){}							\
		void FSAPI	module_deinit(void){}						\
		void FSAPI	query_routine(void)							\
		{														\
			element_list_query( *gauge_header.elements_list );	\
		}														\
		int FSAPI DllMain (PVOID hDLL, UINT32 dwReason, PVOID lpReserved)	\
		{														\
			return TRUE;										\
		}														\
																\
																\
		/* This is the module's gauge header.	*/				\
		GAUGEHDR	gauge_header = {version,					\
									name,						\
									element_list,				\
									query_routine,				\
									install_routine,			\
									initialize_routine,			\
									update_routine,				\
									generate_routine,			\
									draw_routine,				\
									kill_routine,				\
									(char)NULL,					\
									size};						\
																\
																\
		/* This is the module's export table.	*/				\
		GAUGES			Linkage =								\
		{														\
			0x00000013,											\
			module_init,										\
			module_deinit,										\
			0,													\
			0,													\
			NULL,												\
			&gauge_header										\
		};														\
																\
																\
		/* This is the module's import table.	*/				\
		GAUGESIMPORT	ImportTable =							\
		{														\
			{ 0x0000000F, (PPANELS)NULL },						\
			{ 0x00000000, NULL }								\
		};


#pragma pack()

